@@ -57,7 +57,6 @@ func TestBuild(t *testing.T) {
 	c.Assert(b.UseResourceCache(herrors.ErrFeatureNotAvailable), qt.Equals, false)
 	c.Assert(b.UseResourceCache(errors.New("err")), qt.Equals, false)
 	c.Assert(b.UseResourceCache(nil), qt.Equals, false)
-
 }
 
 func TestServer(t *testing.T) {
@@ -98,7 +97,8 @@ status = 301
 	c.Assert(s.MatchHeaders("/foo.jpg"), qt.DeepEquals, []types.KeyValueStr{
 		{Key: "X-Content-Type-Options", Value: "nosniff"},
 		{Key: "X-Frame-Options", Value: "DENY"},
-		{Key: "X-XSS-Protection", Value: "1; mode=block"}})
+		{Key: "X-XSS-Protection", Value: "1; mode=block"},
+	})
 
 	c.Assert(s.MatchRedirect("/foo/bar/baz"), qt.DeepEquals, Redirect{
 		From:   "/foo/**",
@@ -122,7 +122,8 @@ status = 301
 	c.Assert(s.MatchRedirect("/default/index.html"), qt.DeepEquals, Redirect{})
 	c.Assert(s.MatchRedirect("/default/"), qt.DeepEquals, Redirect{})
 
-	for _, errorCase := range []string{`[[server.redirects]]
+	for _, errorCase := range []string{
+		`[[server.redirects]]
 from = "/**"
 to = "/file"
 status = 301`,
@@ -138,5 +139,4 @@ status = 301`,
 		c.Assert(err, qt.Not(qt.IsNil))
 
 	}
-
 }
