@@ -1,4 +1,4 @@
-// Copyright 2017-present The Hugo Authors. All rights reserved.
+// Copyright 2019 The Hugo Authors. All rights reserved.
 //
 // Licensed under the Apache License, Version 2.0 (the "License");
 // you may not use this file except in compliance with the License.
@@ -14,11 +14,7 @@
 package config
 
 import (
-	"strings"
-
-	"github.com/spf13/cast"
-
-	"github.com/spf13/viper"
+	"github.com/gohugoio/hugo/common/types"
 )
 
 // Provider provides the configuration settings for Hugo.
@@ -34,24 +30,22 @@ type Provider interface {
 	IsSet(key string) bool
 }
 
-// FromConfigString creates a config from the given YAML, JSON or TOML config. This is useful in tests.
-func FromConfigString(config, configType string) (Provider, error) {
-	v := viper.New()
-	v.SetConfigType(configType)
-	if err := v.ReadConfig(strings.NewReader(config)); err != nil {
-		return nil, err
-	}
-	return v, nil
-}
-
 // GetStringSlicePreserveString returns a string slice from the given config and key.
 // It differs from the GetStringSlice method in that if the config value is a string,
 // we do not attempt to split it into fields.
 func GetStringSlicePreserveString(cfg Provider, key string) []string {
 	sd := cfg.Get(key)
-	if sds, ok := sd.(string); ok {
-		return []string{sds}
-	} else {
-		return cast.ToStringSlice(sd)
-	}
+	return types.ToStringSlicePreserveString(sd)
+}
+
+// SetBaseTestDefaults provides some common config defaults used in tests.
+func SetBaseTestDefaults(cfg Provider) {
+	cfg.Set("resourceDir", "resources")
+	cfg.Set("contentDir", "content")
+	cfg.Set("dataDir", "data")
+	cfg.Set("i18nDir", "i18n")
+	cfg.Set("layoutDir", "layouts")
+	cfg.Set("assetDir", "assets")
+	cfg.Set("archetypeDir", "archetypes")
+	cfg.Set("publishDir", "public")
 }
