@@ -16,15 +16,14 @@ package create
 
 import (
 	"bytes"
-
-	"github.com/pkg/errors"
-
 	"io"
 	"os"
-	"os/exec"
 	"path/filepath"
 	"strings"
 
+	"github.com/pkg/errors"
+
+	"github.com/gohugoio/hugo/common/hexec"
 	"github.com/gohugoio/hugo/hugofs/files"
 
 	"github.com/gohugoio/hugo/hugofs"
@@ -105,7 +104,11 @@ func NewContent(
 	if editor != "" {
 		jww.FEEDBACK.Printf("Editing %s with %q ...\n", targetPath, editor)
 
-		cmd := exec.Command(editor, contentPath)
+		editorCmd := append(strings.Fields(editor), contentPath)
+		cmd, err := hexec.SafeCommand(editorCmd[0], editorCmd[1:]...)
+		if err != nil {
+			return err
+		}
 		cmd.Stdin = os.Stdin
 		cmd.Stdout = os.Stdout
 		cmd.Stderr = os.Stderr
@@ -130,7 +133,6 @@ func newContentFromDir(
 	sites *hugolib.HugoSites,
 	targetFs afero.Fs,
 	cm archetypeMap, name, targetPath string) error {
-
 	for _, f := range cm.otherFiles {
 		meta := f.Meta()
 		filename := meta.Path()
@@ -195,11 +197,9 @@ func mapArcheTypeDir(
 	ps *helpers.PathSpec,
 	fs afero.Fs,
 	archetypeDir string) (archetypeMap, error) {
-
 	var m archetypeMap
 
 	walkFn := func(path string, fi hugofs.FileMetaInfo, err error) error {
-
 		if err != nil {
 			return err
 		}
@@ -307,7 +307,6 @@ func resolveContentPath(sites *hugolib.HugoSites, fs afero.Fs, targetPath string
 	}
 
 	if siteContentDir == "" {
-
 	}
 
 	if siteContentDir != "" {
@@ -323,7 +322,6 @@ func resolveContentPath(sites *hugolib.HugoSites, fs afero.Fs, targetPath string
 		}
 		return s.PathSpec.AbsPathify(filepath.Join(contentDir, targetPath)), s
 	}
-
 }
 
 // FindArchetype takes a given kind/archetype of content and returns the path
