@@ -17,7 +17,7 @@ import (
 	"bytes"
 	"sync"
 
-	"github.com/kyokomi/emoji"
+	"github.com/kyokomi/emoji/v2"
 )
 
 var (
@@ -30,6 +30,12 @@ var (
 	emojiMaxSize   int
 )
 
+// Emoji returns the emojy given a key, e.g. ":smile:", nil if not found.
+func Emoji(key string) []byte {
+	emojiInit.Do(initEmoji)
+	return emojis[key]
+}
+
 // Emojify "emojifies" the input source.
 // Note that the input byte slice will be modified if needed.
 // See http://www.emoji-cheat-sheet.com/
@@ -87,5 +93,4 @@ func initEmoji() {
 			emojiMaxSize = len(k)
 		}
 	}
-
 }
