@@ -43,7 +43,6 @@ func TestLoadConfig(t *testing.T) {
 	c.Assert(err, qt.IsNil)
 
 	c.Assert(cfg.GetString("paginatePath"), qt.Equals, "side")
-
 }
 
 func TestLoadMultiConfig(t *testing.T) {
@@ -359,7 +358,6 @@ map[string]interface {}{
     },
   },
 }`, got["menu"])
-
 }
 
 func TestPrivacyConfig(t *testing.T) {
@@ -381,7 +379,6 @@ privacyEnhanced = true
 	b.Build(BuildCfg{SkipRender: true})
 
 	c.Assert(b.H.Sites[0].Info.Config().Privacy.YouTube.PrivacyEnhanced, qt.Equals, true)
-
 }
 
 func TestLoadConfigModules(t *testing.T) {
@@ -477,11 +474,9 @@ project n4
 `
 
 	c.Assert(graphb.String(), qt.Equals, expected)
-
 }
 
 func TestLoadConfigWithOsEnvOverrides(t *testing.T) {
-
 	c := qt.New(t)
 
 	baseConfig := `
@@ -492,10 +487,14 @@ intSlice = [5,7,9]
 floatSlice = [3.14, 5.19]
 stringSlice = ["a", "b"]
 
+[params]
+[params.api_config]
+api_key="default_key"
+another_key="default another_key"
+
 [imaging]
 anchor = "smart"
 quality = 75 
-resamplefilter = "CatmullRom"
 `
 
 	b := newTestSitesBuilder(t).WithConfigFile("toml", baseConfig)
@@ -505,9 +504,14 @@ resamplefilter = "CatmullRom"
 		"HUGO_NEW", "new", // key not in config.toml
 		"HUGO_ENABLEGITINFO", "false",
 		"HUGO_IMAGING_ANCHOR", "top",
+		"HUGO_IMAGING_RESAMPLEFILTER", "CatmullRom",
 		"HUGO_STRINGSLICE", `["c", "d"]`,
 		"HUGO_INTSLICE", `[5, 8, 9]`,
 		"HUGO_FLOATSLICE", `[5.32]`,
+		// https://github.com/gohugoio/hugo/issues/7829
+		"HUGOxPARAMSxAPI_CONFIGxAPI_KEY", "new_key",
+		// Delimiters are case sensitive.
+		"HUGOxPARAMSxAPI_CONFIGXANOTHER_KEY", "another_key",
 	)
 
 	b.Build(BuildCfg{})
@@ -519,8 +523,10 @@ resamplefilter = "CatmullRom"
 	c.Assert(cfg.Get("new"), qt.Equals, "new")
 	c.Assert(cfg.Get("imaging.anchor"), qt.Equals, "top")
 	c.Assert(cfg.Get("imaging.quality"), qt.Equals, int64(75))
+	c.Assert(cfg.Get("imaging.resamplefilter"), qt.Equals, "CatmullRom")
 	c.Assert(cfg.Get("stringSlice"), qt.DeepEquals, []interface{}{"c", "d"})
 	c.Assert(cfg.Get("floatSlice"), qt.DeepEquals, []interface{}{5.32})
 	c.Assert(cfg.Get("intSlice"), qt.DeepEquals, []interface{}{5, 8, 9})
-
+	c.Assert(cfg.Get("params.api_config.api_key"), qt.Equals, "new_key")
+	c.Assert(cfg.Get("params.api_config.another_key"), qt.Equals, "default another_key")
 }
