@@ -41,10 +41,9 @@ const (
 func newPagesCollector(
 	sp *source.SourceSpec,
 	contentMap *pageMaps,
-	logger *loggers.Logger,
+	logger loggers.Logger,
 	contentTracker *contentChangeMap,
 	proc pagesCollectorProcessorProvider, filenames ...string) *pagesCollector {
-
 	return &pagesCollector{
 		fs:         sp.SourceFs,
 		contentMap: contentMap,
@@ -75,7 +74,6 @@ func (b *fileinfoBundle) containsResource(name string) bool {
 	}
 
 	return false
-
 }
 
 type pageBundles map[string]*fileinfoBundle
@@ -83,7 +81,7 @@ type pageBundles map[string]*fileinfoBundle
 type pagesCollector struct {
 	sp     *source.SourceSpec
 	fs     afero.Fs
-	logger *loggers.Logger
+	logger loggers.Logger
 
 	contentMap *pageMaps
 
@@ -100,7 +98,7 @@ type pagesCollector struct {
 // That is, if a front matter cascade section is removed, added or edited.
 // If this is the case we must re-evaluate its descendants.
 func (c *pagesCollector) isCascadingEdit(dir contentDirKey) (bool, string) {
-	// This is eiter a section or a taxonomy node. Find it.
+	// This is either a section or a taxonomy node. Find it.
 	prefix := cleanTreeKey(dir.dirname)
 
 	section := "/"
@@ -137,6 +135,7 @@ func (c *pagesCollector) isCascadingEdit(dir contentDirKey) (bool, string) {
 		hasCascade := n.p.bucket.cascade != nil && len(n.p.bucket.cascade) > 0
 		if !ok {
 			isCascade = hasCascade
+
 			return true
 		}
 
@@ -145,10 +144,14 @@ func (c *pagesCollector) isCascadingEdit(dir contentDirKey) (bool, string) {
 			return true
 		}
 
-		isCascade = !reflect.DeepEqual(cascade1, n.p.bucket.cascade)
+		for _, v := range n.p.bucket.cascade {
+			isCascade = !reflect.DeepEqual(cascade1, v)
+			if isCascade {
+				break
+			}
+		}
 
 		return true
-
 	})
 
 	return isCascade, section
@@ -187,6 +190,7 @@ func (c *pagesCollector) Collect() (collectErr error) {
 				collectErr = c.collectDir(dir.dirname, true, nil)
 			case bundleBranch:
 				isCascading, section := c.isCascadingEdit(dir)
+
 				if isCascading {
 					c.contentMap.deleteSection(section)
 				}
@@ -206,7 +210,6 @@ func (c *pagesCollector) Collect() (collectErr error) {
 	}
 
 	return
-
 }
 
 func (c *pagesCollector) isBundleHeader(fi hugofs.FileMetaInfo) bool {
@@ -275,7 +278,7 @@ func (c *pagesCollector) addToBundle(info hugofs.FileMetaInfo, btyp bundleDirTyp
 			if btyp == bundleBranch {
 				// No special logic for branch bundles.
 				// Every language needs its own _index.md file.
-				// Also, we only clone bundle headers for lonsesome, bundled,
+				// Also, we only clone bundle headers for lonesome, bundled,
 				// content files.
 				return c.handleFiles(info)
 			}
@@ -336,7 +339,6 @@ func (c *pagesCollector) collectDir(dirname string, partial bool, inFilter func(
 		dir hugofs.FileMetaInfo,
 		path string,
 		readdir []hugofs.FileMetaInfo) error {
-
 		if btype > bundleNot && c.tracker != nil {
 			c.tracker.add(path, btype)
 		}
@@ -360,7 +362,6 @@ func (c *pagesCollector) collectDir(dirname string, partial bool, inFilter func(
 		}
 
 		return nil
-
 	}
 
 	filter := func(fim hugofs.FileMetaInfo) bool {
@@ -434,7 +435,7 @@ func (c *pagesCollector) collectDir(dirname string, partial bool, inFilter func(
 			// The branch variant will win because of sort order, but log
 			// a warning about it.
 			if thisBtype > bundleNot && btype > bundleNot && thisBtype != btype {
-				c.logger.WARN.Printf("Content directory %q have both index.* and _index.* files, pick one.", dir.Meta().Filename())
+				c.logger.Warnf("Content directory %q have both index.* and _index.* files, pick one.", dir.Meta().Filename())
 				// Reclassify it so it will be handled as a content file inside the
 				// section, which is in line with the <= 0.55 behaviour.
 				meta["classifier"] = files.ContentClassContent
@@ -462,7 +463,6 @@ func (c *pagesCollector) collectDir(dirname string, partial bool, inFilter func(
 
 		// Keep walking.
 		return readdir, nil
-
 	}
 
 	var postHook hugofs.WalkHook
@@ -497,14 +497,13 @@ func (c *pagesCollector) collectDir(dirname string, partial bool, inFilter func(
 		Info:     fim,
 		HookPre:  preHook,
 		HookPost: postHook,
-		WalkFn:   wfn})
+		WalkFn:   wfn,
+	})
 
 	return w.Walk()
-
 }
 
 func (c *pagesCollector) handleBundleBranch(readdir []hugofs.FileMetaInfo) error {
-
 	// Maps bundles to its language.
 	bundles := pageBundles{}
 
@@ -535,7 +534,6 @@ func (c *pagesCollector) handleBundleBranch(readdir []hugofs.FileMetaInfo) error
 	}
 
 	return c.handleFiles(contentFiles...)
-
 }
 
 func (c *pagesCollector) handleBundleLeaf(dir hugofs.FileMetaInfo, path string, readdir []hugofs.FileMetaInfo) error {
@@ -551,7 +549,6 @@ func (c *pagesCollector) handleBundleLeaf(dir hugofs.FileMetaInfo, path string,
 		}
 
 		return c.addToBundle(info, bundleLeaf, bundles)
-
 	}
 
 	// Start a new walker from the given path.
@@ -561,14 +558,14 @@ func (c *pagesCollector) handleBundleLeaf(dir hugofs.FileMetaInfo, path string,
 		Logger:     c.logger,
 		Info:       dir,
 		DirEntries: readdir,
-		WalkFn:     walk})
+		WalkFn:     walk,
+	})
 
 	if err := w.Walk(); err != nil {
 		return err
 	}
 
 	return c.proc.Process(bundles)
-
 }
 
 func (c *pagesCollector) handleFiles(fis ...hugofs.FileMetaInfo) error {
