@@ -14,17 +14,24 @@
 package hugolib
 
 import (
+	"bytes"
 	"fmt"
 	"io"
 	"math/rand"
 	"os"
-	"os/exec"
+
+	"github.com/gohugoio/hugo/resources/resource_transformers/tocss/dartsass"
+
 	"path/filepath"
 	"runtime"
 	"strings"
 	"testing"
 	"time"
 
+	"github.com/gohugoio/hugo/common/hexec"
+
+	jww "github.com/spf13/jwalterweatherman"
+
 	"github.com/gohugoio/hugo/common/herrors"
 
 	"github.com/gohugoio/hugo/htesting"
@@ -40,33 +47,44 @@ import (
 )
 
 func TestSCSSWithIncludePaths(t *testing.T) {
-	if !scss.Supports() {
-		t.Skip("Skip SCSS")
-	}
 	c := qt.New(t)
-	workDir, clean, err := htesting.CreateTempDir(hugofs.Os, "hugo-scss-include")
-	c.Assert(err, qt.IsNil)
-	defer clean()
 
-	v := viper.New()
-	v.Set("workingDir", workDir)
-	b := newTestSitesBuilder(t).WithLogger(loggers.NewErrorLogger())
-	// Need to use OS fs for this.
-	b.Fs = hugofs.NewDefault(v)
-	b.WithWorkingDir(workDir)
-	b.WithViper(v)
+	for _, test := range []struct {
+		name     string
+		supports func() bool
+	}{
+		{"libsass", func() bool { return scss.Supports() }},
+		{"dartsass", func() bool { return dartsass.Supports() }},
+	} {
 
-	fooDir := filepath.Join(workDir, "node_modules", "foo")
-	scssDir := filepath.Join(workDir, "assets", "scss")
-	c.Assert(os.MkdirAll(fooDir, 0777), qt.IsNil)
-	c.Assert(os.MkdirAll(filepath.Join(workDir, "content", "sect"), 0777), qt.IsNil)
-	c.Assert(os.MkdirAll(filepath.Join(workDir, "data"), 0777), qt.IsNil)
-	c.Assert(os.MkdirAll(filepath.Join(workDir, "i18n"), 0777), qt.IsNil)
-	c.Assert(os.MkdirAll(filepath.Join(workDir, "layouts", "shortcodes"), 0777), qt.IsNil)
-	c.Assert(os.MkdirAll(filepath.Join(workDir, "layouts", "_default"), 0777), qt.IsNil)
-	c.Assert(os.MkdirAll(filepath.Join(scssDir), 0777), qt.IsNil)
+		c.Run(test.name, func(c *qt.C) {
+			if !test.supports() {
+				c.Skip(fmt.Sprintf("Skip %s", test.name))
+			}
 
-	b.WithSourceFile(filepath.Join(fooDir, "_moo.scss"), `
+			workDir, clean, err := htesting.CreateTempDir(hugofs.Os, fmt.Sprintf("hugo-scss-include-%s", test.name))
+			c.Assert(err, qt.IsNil)
+			defer clean()
+
+			v := viper.New()
+			v.Set("workingDir", workDir)
+			b := newTestSitesBuilder(c).WithLogger(loggers.NewErrorLogger())
+			// Need to use OS fs for this.
+			b.Fs = hugofs.NewDefault(v)
+			b.WithWorkingDir(workDir)
+			b.WithViper(v)
+
+			fooDir := filepath.Join(workDir, "node_modules", "foo")
+			scssDir := filepath.Join(workDir, "assets", "scss")
+			c.Assert(os.MkdirAll(fooDir, 0777), qt.IsNil)
+			c.Assert(os.MkdirAll(filepath.Join(workDir, "content", "sect"), 0777), qt.IsNil)
+			c.Assert(os.MkdirAll(filepath.Join(workDir, "data"), 0777), qt.IsNil)
+			c.Assert(os.MkdirAll(filepath.Join(workDir, "i18n"), 0777), qt.IsNil)
+			c.Assert(os.MkdirAll(filepath.Join(workDir, "layouts", "shortcodes"), 0777), qt.IsNil)
+			c.Assert(os.MkdirAll(filepath.Join(workDir, "layouts", "_default"), 0777), qt.IsNil)
+			c.Assert(os.MkdirAll(filepath.Join(scssDir), 0777), qt.IsNil)
+
+			b.WithSourceFile(filepath.Join(fooDir, "_moo.scss"), `
 $moolor: #fff;
 
 moo {
@@ -74,48 +92,63 @@ moo {
 }
 `)
 
-	b.WithSourceFile(filepath.Join(scssDir, "main.scss"), `
+			b.WithSourceFile(filepath.Join(scssDir, "main.scss"), `
 @import "moo";
 
 `)
 
-	b.WithTemplatesAdded("index.html", `
-{{ $cssOpts := (dict "includePaths" (slice "node_modules/foo" ) ) }}
+			b.WithTemplatesAdded("index.html", fmt.Sprintf(`
+{{ $cssOpts := (dict "includePaths" (slice "node_modules/foo") "transpiler" %q ) }}
 {{ $r := resources.Get "scss/main.scss" |  toCSS $cssOpts  | minify  }}
 T1: {{ $r.Content }}
-`)
-	b.Build(BuildCfg{})
+`, test.name))
+			b.Build(BuildCfg{})
 
-	b.AssertFileContent(filepath.Join(workDir, "public/index.html"), `T1: moo{color:#fff}`)
+			b.AssertFileContent(filepath.Join(workDir, "public/index.html"), `T1: moo{color:#fff}`)
+		})
+
+	}
 
 }
 
 func TestSCSSWithRegularCSSImport(t *testing.T) {
-	if !scss.Supports() {
-		t.Skip("Skip SCSS")
-	}
 	c := qt.New(t)
-	workDir, clean, err := htesting.CreateTempDir(hugofs.Os, "hugo-scss-include")
-	c.Assert(err, qt.IsNil)
-	defer clean()
 
-	v := viper.New()
-	v.Set("workingDir", workDir)
-	b := newTestSitesBuilder(t).WithLogger(loggers.NewErrorLogger())
-	// Need to use OS fs for this.
-	b.Fs = hugofs.NewDefault(v)
-	b.WithWorkingDir(workDir)
-	b.WithViper(v)
+	for _, test := range []struct {
+		name     string
+		supports func() bool
+	}{
+		{"libsass", func() bool { return scss.Supports() }},
+		{"dartsass", func() bool { return dartsass.Supports() }},
+	} {
 
-	scssDir := filepath.Join(workDir, "assets", "scss")
-	c.Assert(os.MkdirAll(filepath.Join(workDir, "content", "sect"), 0777), qt.IsNil)
-	c.Assert(os.MkdirAll(filepath.Join(workDir, "data"), 0777), qt.IsNil)
-	c.Assert(os.MkdirAll(filepath.Join(workDir, "i18n"), 0777), qt.IsNil)
-	c.Assert(os.MkdirAll(filepath.Join(workDir, "layouts", "shortcodes"), 0777), qt.IsNil)
-	c.Assert(os.MkdirAll(filepath.Join(workDir, "layouts", "_default"), 0777), qt.IsNil)
-	c.Assert(os.MkdirAll(filepath.Join(scssDir), 0777), qt.IsNil)
+		c.Run(test.name, func(c *qt.C) {
+			if !test.supports() {
+				c.Skip(fmt.Sprintf("Skip %s", test.name))
+			}
 
-	b.WithSourceFile(filepath.Join(scssDir, "_moo.scss"), `
+			workDir, clean, err := htesting.CreateTempDir(hugofs.Os, fmt.Sprintf("hugo-scss-include-regular-%s", test.name))
+			c.Assert(err, qt.IsNil)
+			defer clean()
+
+			v := viper.New()
+			v.Set("workingDir", workDir)
+			b := newTestSitesBuilder(c).WithLogger(loggers.NewErrorLogger())
+			// Need to use OS fs for this.
+			b.Fs = hugofs.NewDefault(v)
+			b.WithWorkingDir(workDir)
+			b.WithViper(v)
+
+			scssDir := filepath.Join(workDir, "assets", "scss")
+			c.Assert(os.MkdirAll(filepath.Join(workDir, "content", "sect"), 0777), qt.IsNil)
+			c.Assert(os.MkdirAll(filepath.Join(workDir, "data"), 0777), qt.IsNil)
+			c.Assert(os.MkdirAll(filepath.Join(workDir, "i18n"), 0777), qt.IsNil)
+			c.Assert(os.MkdirAll(filepath.Join(workDir, "layouts", "shortcodes"), 0777), qt.IsNil)
+			c.Assert(os.MkdirAll(filepath.Join(workDir, "layouts", "_default"), 0777), qt.IsNil)
+			c.Assert(os.MkdirAll(filepath.Join(scssDir), 0777), qt.IsNil)
+			b.WithSourceFile(filepath.Join(scssDir, "regular.css"), ``)
+			b.WithSourceFile(filepath.Join(scssDir, "another.css"), ``)
+			b.WithSourceFile(filepath.Join(scssDir, "_moo.scss"), `
 $moolor: #fff;
 
 moo {
@@ -123,7 +156,7 @@ moo {
 }
 `)
 
-	b.WithSourceFile(filepath.Join(scssDir, "main.scss"), `
+			b.WithSourceFile(filepath.Join(scssDir, "main.scss"), `
 @import "moo";
 @import "regular.css";
 @import "moo";
@@ -132,13 +165,17 @@ moo {
 /* foo */
 `)
 
-	b.WithTemplatesAdded("index.html", `
-{{ $r := resources.Get "scss/main.scss" |  toCSS  }}
+			b.WithTemplatesAdded("index.html", fmt.Sprintf(`
+{{ $r := resources.Get "scss/main.scss" |  toCSS (dict "transpiler" %q)  }}
 T1: {{ $r.Content | safeHTML }}
-`)
-	b.Build(BuildCfg{})
+`, test.name))
+			b.Build(BuildCfg{})
 
-	b.AssertFileContent(filepath.Join(workDir, "public/index.html"), `
+			if test.name == "libsass" {
+				// LibSass does not support regular CSS imports. There
+				// is an open bug about it that probably will never be resolved.
+				// Hugo works around this by preserving them in place:
+				b.AssertFileContent(filepath.Join(workDir, "public/index.html"), `
  T1: moo {
  color: #fff; }
 
@@ -150,48 +187,79 @@ moo {
 /* foo */
         
 `)
+			} else {
+				// Dart Sass does not follow regular CSS import, but they
+				// get pulled to the top.
+				b.AssertFileContent(filepath.Join(workDir, "public/index.html"), `T1: @import "regular.css";
+@import "another.css";
+moo {
+  color: #fff;
+}
+
+moo {
+  color: #fff;
+}
+
+/* foo */`)
+
+			}
+		})
+	}
 
 }
 
 func TestSCSSWithThemeOverrides(t *testing.T) {
-	if !scss.Supports() {
-		t.Skip("Skip SCSS")
-	}
 	c := qt.New(t)
-	workDir, clean1, err := htesting.CreateTempDir(hugofs.Os, "hugo-scss-include")
-	c.Assert(err, qt.IsNil)
-	defer clean1()
 
-	theme := "mytheme"
-	themesDir := filepath.Join(workDir, "themes")
-	themeDirs := filepath.Join(themesDir, theme)
-	v := viper.New()
-	v.Set("workingDir", workDir)
-	v.Set("theme", theme)
-	b := newTestSitesBuilder(t).WithLogger(loggers.NewErrorLogger())
-	// Need to use OS fs for this.
-	b.Fs = hugofs.NewDefault(v)
-	b.WithWorkingDir(workDir)
-	b.WithViper(v)
+	for _, test := range []struct {
+		name     string
+		supports func() bool
+	}{
+		{"libsass", func() bool { return scss.Supports() }},
+		{"dartsass", func() bool { return dartsass.Supports() }},
+	} {
 
-	fooDir := filepath.Join(workDir, "node_modules", "foo")
-	scssDir := filepath.Join(workDir, "assets", "scss")
-	scssThemeDir := filepath.Join(themeDirs, "assets", "scss")
-	c.Assert(os.MkdirAll(fooDir, 0777), qt.IsNil)
-	c.Assert(os.MkdirAll(filepath.Join(workDir, "content", "sect"), 0777), qt.IsNil)
-	c.Assert(os.MkdirAll(filepath.Join(workDir, "data"), 0777), qt.IsNil)
-	c.Assert(os.MkdirAll(filepath.Join(workDir, "i18n"), 0777), qt.IsNil)
-	c.Assert(os.MkdirAll(filepath.Join(workDir, "layouts", "shortcodes"), 0777), qt.IsNil)
-	c.Assert(os.MkdirAll(filepath.Join(workDir, "layouts", "_default"), 0777), qt.IsNil)
-	c.Assert(os.MkdirAll(filepath.Join(scssDir, "components"), 0777), qt.IsNil)
-	c.Assert(os.MkdirAll(filepath.Join(scssThemeDir, "components"), 0777), qt.IsNil)
+		c.Run(test.name, func(c *qt.C) {
+			if !test.supports() {
+				c.Skip(fmt.Sprintf("Skip %s", test.name))
+			}
 
-	b.WithSourceFile(filepath.Join(scssThemeDir, "components", "_imports.scss"), `
+			workDir, clean1, err := htesting.CreateTempDir(hugofs.Os, fmt.Sprintf("hugo-scss-include-theme-overrides-%s", test.name))
+			c.Assert(err, qt.IsNil)
+			defer clean1()
+
+			theme := "mytheme"
+			themesDir := filepath.Join(workDir, "themes")
+			themeDirs := filepath.Join(themesDir, theme)
+			v := viper.New()
+			v.Set("workingDir", workDir)
+			v.Set("theme", theme)
+			b := newTestSitesBuilder(c).WithLogger(loggers.NewErrorLogger())
+			// Need to use OS fs for this.
+			b.Fs = hugofs.NewDefault(v)
+			b.WithWorkingDir(workDir)
+			b.WithViper(v)
+
+			fooDir := filepath.Join(workDir, "node_modules", "foo")
+			scssDir := filepath.Join(workDir, "assets", "scss")
+			scssThemeDir := filepath.Join(themeDirs, "assets", "scss")
+			c.Assert(os.MkdirAll(fooDir, 0777), qt.IsNil)
+			c.Assert(os.MkdirAll(filepath.Join(workDir, "content", "sect"), 0777), qt.IsNil)
+			c.Assert(os.MkdirAll(filepath.Join(workDir, "data"), 0777), qt.IsNil)
+			c.Assert(os.MkdirAll(filepath.Join(workDir, "i18n"), 0777), qt.IsNil)
+			c.Assert(os.MkdirAll(filepath.Join(workDir, "layouts", "shortcodes"), 0777), qt.IsNil)
+			c.Assert(os.MkdirAll(filepath.Join(workDir, "layouts", "_default"), 0777), qt.IsNil)
+			c.Assert(os.MkdirAll(filepath.Join(scssDir, "components"), 0777), qt.IsNil)
+			c.Assert(os.MkdirAll(filepath.Join(scssThemeDir, "components"), 0777), qt.IsNil)
+
+			b.WithSourceFile(filepath.Join(scssThemeDir, "components", "_imports.scss"), `
 @import "moo";
 @import "_boo";
+@import "_zoo";
+
 `)
 
-	b.WithSourceFile(filepath.Join(scssThemeDir, "components", "_moo.scss"), `
+			b.WithSourceFile(filepath.Join(scssThemeDir, "components", "_moo.scss"), `
 $moolor: #fff;
 
 moo {
@@ -199,7 +267,16 @@ moo {
 }
 `)
 
-	b.WithSourceFile(filepath.Join(scssThemeDir, "components", "_boo.scss"), `
+			// Only in theme.
+			b.WithSourceFile(filepath.Join(scssThemeDir, "components", "_zoo.scss"), `
+$zoolor: pink;
+
+zoo {
+  color: $zoolor;
+}
+`)
+
+			b.WithSourceFile(filepath.Join(scssThemeDir, "components", "_boo.scss"), `
 $boolor: orange;
 
 boo {
@@ -207,12 +284,12 @@ boo {
 }
 `)
 
-	b.WithSourceFile(filepath.Join(scssThemeDir, "main.scss"), `
+			b.WithSourceFile(filepath.Join(scssThemeDir, "main.scss"), `
 @import "components/imports";
 
 `)
 
-	b.WithSourceFile(filepath.Join(scssDir, "components", "_moo.scss"), `
+			b.WithSourceFile(filepath.Join(scssDir, "components", "_moo.scss"), `
 $moolor: #ccc;
 
 moo {
@@ -220,7 +297,7 @@ moo {
 }
 `)
 
-	b.WithSourceFile(filepath.Join(scssDir, "components", "_boo.scss"), `
+			b.WithSourceFile(filepath.Join(scssDir, "components", "_boo.scss"), `
 $boolor: green;
 
 boo {
@@ -228,23 +305,43 @@ boo {
 }
 `)
 
-	b.WithTemplatesAdded("index.html", `
-{{ $cssOpts := (dict "includePaths" (slice "node_modules/foo" ) ) }}
+			b.WithTemplatesAdded("index.html", fmt.Sprintf(`
+{{ $cssOpts := (dict "includePaths" (slice "node_modules/foo" ) "transpiler" %q ) }}
 {{ $r := resources.Get "scss/main.scss" |  toCSS $cssOpts  | minify  }}
 T1: {{ $r.Content }}
-`)
-	b.Build(BuildCfg{})
+`, test.name))
+			b.Build(BuildCfg{})
 
-	b.AssertFileContent(filepath.Join(workDir, "public/index.html"), `T1: moo{color:#ccc}boo{color:green}`)
+			b.AssertFileContent(
+				filepath.Join(workDir, "public/index.html"),
+				`T1: moo{color:#ccc}boo{color:green}zoo{color:pink}`,
+			)
+		})
+	}
 
 }
 
 // https://github.com/gohugoio/hugo/issues/6274
 func TestSCSSWithIncludePathsSass(t *testing.T) {
+	c := qt.New(t)
+
+	for _, test := range []struct {
+		name     string
+		supports func() bool
+	}{
+		{"libsass", func() bool { return scss.Supports() }},
+		{"dartsass", func() bool { return dartsass.Supports() }},
+	} {
+
+		c.Run(test.name, func(c *qt.C) {
+			if !test.supports() {
+				c.Skip(fmt.Sprintf("Skip %s", test.name))
+			}
+		})
+	}
 	if !scss.Supports() {
 		t.Skip("Skip SCSS")
 	}
-	c := qt.New(t)
 	workDir, clean1, err := htesting.CreateTempDir(hugofs.Os, "hugo-scss-includepaths")
 	c.Assert(err, qt.IsNil)
 	defer clean1()
@@ -284,7 +381,6 @@ T1: {{ $r.Content }}
 	b.Build(BuildCfg{})
 
 	b.AssertFileContent(filepath.Join(workDir, "public/index.html"), `T1: foo{color:#ccc}`)
-
 }
 
 func TestResourceChainBasic(t *testing.T) {
@@ -384,16 +480,14 @@ End.`)
 	b.AssertFileContent("public/index.html",
 		`Start.
 HELLO: /hello.min.a2d1cb24f24b322a7dad520414c523e9.html|Integrity: md5-otHLJPJLMip9rVIEFMUj6Q==|MediaType: text/html
-HELLO2: Name: hello.html|Content: <h1>Hello World!</h1>|Title: hello.html|ResourceType: html
+HELLO2: Name: hello.html|Content: <h1>Hello World!</h1>|Title: hello.html|ResourceType: text
 End.`)
 
 	b.AssertFileContent("public/page1/index.html", `HELLO: /hello.min.a2d1cb24f24b322a7dad520414c523e9.html`)
 	b.AssertFileContent("public/page2/index.html", `HELLO: /hello.min.a2d1cb24f24b322a7dad520414c523e9.html`)
-
 }
 
 func BenchmarkResourceChainPostProcess(b *testing.B) {
-
 	for i := 0; i < b.N; i++ {
 		b.StopTimer()
 		s := newTestSitesBuilder(b)
@@ -426,7 +520,6 @@ End.
 		s.Build(BuildCfg{})
 
 	}
-
 }
 
 func TestResourceChains(t *testing.T) {
@@ -467,7 +560,6 @@ T6: {{ $bundle1.Permalink }}
 
 			c.Assert(b.CheckExists("public/styles/templ.min.css"), qt.Equals, false)
 			b.AssertFileContent("public/styles/bundle1.css", `.home{color:blue}body{color:#333}`)
-
 		}},
 
 		{"minify", func() bool { return true }, func(b *sitesBuilder) {
@@ -545,10 +637,8 @@ T3: Content: {{ $combinedJs.Content }}|{{ $combinedJs.RelPermalink }}
 Fingerprinted: {{ $fingerprinted.RelPermalink }}
 `)
 		}, func(b *sitesBuilder) {
-
 			b.AssertFileContent("public/index.html", "Fingerprinted: /bundle/concat.b5d4045c3f466fa91fe2cc6abe79232a1a57cdf104f7a26e716e0a1e2789df78.txt")
 			b.AssertFileContent("public/bundle/concat.b5d4045c3f466fa91fe2cc6abe79232a1a57cdf104f7a26e716e0a1e2789df78.txt", "ABC")
-
 		}},
 
 		{"fromstring", func() bool { return true }, func(b *sitesBuilder) {
@@ -556,11 +646,9 @@ Fingerprinted: {{ $fingerprinted.RelPermalink }}
 {{ $r := "Hugo Rocks!" | resources.FromString "rocks/hugo.txt" }}
 {{ $r.Content }}|{{ $r.RelPermalink }}|{{ $r.Permalink }}|{{ $r.MediaType.Type }}
 `)
-
 		}, func(b *sitesBuilder) {
 			b.AssertFileContent("public/index.html", `Hugo Rocks!|/rocks/hugo.txt|http://example.com/rocks/hugo.txt|text/plain`)
 			b.AssertFileContent("public/rocks/hugo.txt", "Hugo Rocks!")
-
 		}},
 		{"execute-as-template", func() bool {
 			return true
@@ -574,10 +662,8 @@ T1: {{ $var }}
 {{ $result := "{{ .Kind | upper }}" | resources.FromString "mytpl.txt" | resources.ExecuteAsTemplate "result.txt" . }}
 T2: {{ $result.Content }}|{{ $result.RelPermalink}}|{{$result.MediaType.Type }}
 `)
-
 		}, func(b *sitesBuilder) {
 			b.AssertFileContent("public/index.html", `T2: HOME|/result.txt|text/plain`, `T1: Hugo Home`)
-
 		}},
 		{"fingerprint", func() bool { return true }, func(b *sitesBuilder) {
 			b.WithTemplates("home.html", `
@@ -599,7 +685,6 @@ T4: {{ $r2.Data.Integrity }}|
 			b.AssertFileContent("public/index.html", `T2: ab|/rocks/hugo.2d408a0717ec188158278a796c689044361dc6fdde28d6f04973b80896e1823975cdbf12eb63f9e0591328ee235d80e9b5bf1aa6a44f4617ff3caf6400eb172d.txt|text/plain|sha512-LUCKBxfsGIFYJ4p5bGiQRDYdxv3eKNbwSXO4CJbhgjl1zb8S62P54FkTKO4jXYDptb8apqRPRhf/PK9kAOsXLQ==|`)
 			b.AssertFileContent("public/index.html", `T3: ab|/rocks/hugo.187ef4436122d1cc2f40dc2b92f0eba0.txt|text/plain|md5-GH70Q2Ei0cwvQNwrkvDroA==|`)
 			b.AssertFileContent("public/index.html", `T4: sha256-Hgu9bGhroFC46wP/7txk/cnYCUf86CGrvl1tyNJSxaw=|`)
-
 		}},
 		// https://github.com/gohugoio/hugo/issues/5226
 		{"baseurl-path", func() bool { return true }, func(b *sitesBuilder) {
@@ -610,7 +695,6 @@ T1: {{ $r1.Permalink }}|{{ $r1.RelPermalink }}
 `)
 		}, func(b *sitesBuilder) {
 			b.AssertFileContent("public/index.html", `T1: https://example.com/hugo/rocks/hugo.txt|/hugo/rocks/hugo.txt`)
-
 		}},
 
 		// https://github.com/gohugoio/hugo/issues/4944
@@ -624,7 +708,6 @@ Inline: {{ $cssInline.Content }}
 Publish 1: {{ $cssPublish1.Content }} {{ $cssPublish1.RelPermalink }}
 Publish 2: {{ $cssPublish2.Permalink }}
 `)
-
 		}, func(b *sitesBuilder) {
 			b.AssertFileContent("public/index.html",
 				`Inline: body{color:green}`,
@@ -761,7 +844,6 @@ $color: #333;
 			test.prepare(b)
 			b.Build(BuildCfg{})
 			test.verify(b)
-
 		})
 	}
 }
@@ -780,7 +862,6 @@ func TestMultiSiteResource(t *testing.T) {
 	c.Assert(b.CheckExists("public/en/text/pipes.txt"), qt.Equals, false)
 	b.AssertFileContent("public/en/index.html", "Default Home Page", "String Resource: /blog/text/pipes.txt")
 	b.AssertFileContent("public/text/pipes.txt", "Hugo Pipes")
-
 }
 
 func TestResourcesMatch(t *testing.T) {
@@ -837,11 +918,10 @@ Hello2: Hello
 Hello1: Bonjour
 Hello2: Bonjour
 `)
-
 }
 
 func TestResourceChainPostCSS(t *testing.T) {
-	if !isCI() {
+	if !htesting.IsCI() {
 		t.Skip("skip (relative) long running modules test when running locally")
 	}
 
@@ -868,6 +948,10 @@ func TestResourceChainPostCSS(t *testing.T) {
 
 	postcssConfig := `
 console.error("Hugo Environment:", process.env.HUGO_ENVIRONMENT );
+// https://github.com/gohugoio/hugo/issues/7656
+console.error("package.json:", process.env.HUGO_FILE_PACKAGE_JSON );
+console.error("PostCSS Config File:", process.env.HUGO_FILE_POSTCSS_CONFIG_JS );
+
 
 module.exports = {
   plugins: [
@@ -893,10 +977,13 @@ h1 {
 	c.Assert(err, qt.IsNil)
 	defer clean()
 
+	var logBuf bytes.Buffer
+
 	newTestBuilder := func(v *viper.Viper) *sitesBuilder {
 		v.Set("workingDir", workDir)
 		v.Set("disableKinds", []string{"taxonomy", "term", "page"})
-		b := newTestSitesBuilder(t).WithLogger(loggers.NewWarningLogger())
+		logger := loggers.NewBasicLoggerForWriter(jww.LevelInfo, &logBuf)
+		b := newTestSitesBuilder(t).WithLogger(logger)
 		// Need to use OS fs for this.
 		b.Fs = hugofs.NewDefault(v)
 		b.WithWorkingDir(workDir)
@@ -940,16 +1027,15 @@ class-in-b {
 	b.WithSourceFile("postcss.config.js", postcssConfig)
 
 	b.Assert(os.Chdir(workDir), qt.IsNil)
-	_, err = exec.Command("npm", "install").CombinedOutput()
+	cmd, err := hexec.SafeCommand("npm", "install")
+	_, err = cmd.CombinedOutput()
 	b.Assert(err, qt.IsNil)
-
-	out, _ := captureStderr(func() error {
-		b.Build(BuildCfg{})
-		return nil
-	})
+	b.Build(BuildCfg{})
 
 	// Make sure Node sees this.
-	b.Assert(out, qt.Contains, "Hugo Environment: production")
+	b.Assert(logBuf.String(), qt.Contains, "Hugo Environment: production")
+	b.Assert(logBuf.String(), qt.Contains, fmt.Sprintf("PostCSS Config File: %s/postcss.config.js", workDir))
+	b.Assert(logBuf.String(), qt.Contains, fmt.Sprintf("package.json: %s/package.json", workDir))
 
 	b.AssertFileContent("public/index.html", `
 Styles RelPermalink: /css/styles.css
@@ -961,7 +1047,6 @@ Styles Content: Len: 770878|
 
 		b.Assert(strings.Contains(content, "class-in-a"), qt.Equals, true)
 		b.Assert(strings.Contains(content, "class-in-b"), qt.Equals, true)
-
 	}
 
 	assertCss(b)
@@ -1021,7 +1106,6 @@ class-in-b {
 	build("always", true)
 	build("fallback", true)
 	build("never", true)
-
 }
 
 func TestResourceMinifyDisabled(t *testing.T) {
