@@ -51,7 +51,6 @@ func TestTemplateLookupOrder(t *testing.T) {
 			func(t *testing.T) {
 				writeSource(t, fs, filepath.Join("layouts", "section", "sect1-baseof.html"), `Base: {{block "main" .}}block{{end}}`)
 				writeSource(t, fs, filepath.Join("layouts", "section", "sect1.html"), `{{define "main"}}sect{{ end }}`)
-
 			},
 			func(t *testing.T) {
 				th.assertFileContent(filepath.Join("public", "sect1", "index.html"), "Base: sect")
@@ -62,7 +61,6 @@ func TestTemplateLookupOrder(t *testing.T) {
 			func(t *testing.T) {
 				writeSource(t, fs, filepath.Join("layouts", "baseof.html"), `Base: {{block "main" .}}block{{end}}`)
 				writeSource(t, fs, filepath.Join("layouts", "index.html"), `{{define "main"}}index{{ end }}`)
-
 			},
 			func(t *testing.T) {
 				th.assertFileContent(filepath.Join("public", "index.html"), "Base: index")
@@ -73,7 +71,6 @@ func TestTemplateLookupOrder(t *testing.T) {
 			func(t *testing.T) {
 				writeSource(t, fs, filepath.Join("layouts", "_default", "list-baseof.html"), `Base: {{block "main" .}}block{{end}}`)
 				writeSource(t, fs, filepath.Join("layouts", "_default", "list.html"), `{{define "main"}}list{{ end }}`)
-
 			},
 			func(t *testing.T) {
 				th.assertFileContent(filepath.Join("public", "sect1", "index.html"), "Base: list")
@@ -84,7 +81,6 @@ func TestTemplateLookupOrder(t *testing.T) {
 			func(t *testing.T) {
 				writeSource(t, fs, filepath.Join("layouts", "_default", "baseof.html"), `Base: {{block "main" .}}block{{end}}`)
 				writeSource(t, fs, filepath.Join("layouts", "_default", "list.html"), `{{define "main"}}list{{ end }}`)
-
 			},
 			func(t *testing.T) {
 				th.assertFileContent(filepath.Join("public", "sect1", "index.html"), "Base: list")
@@ -97,7 +93,6 @@ func TestTemplateLookupOrder(t *testing.T) {
 				writeSource(t, fs, filepath.Join("layouts", "section", "sect1-baseof.html"), `Base: {{block "main" .}}block{{end}}`)
 				writeSource(t, fs, filepath.Join("themes", "mytheme", "layouts", "section", "sect-baseof.html"), `Base Theme: {{block "main" .}}block{{end}}`)
 				writeSource(t, fs, filepath.Join("layouts", "section", "sect1.html"), `{{define "main"}}sect{{ end }}`)
-
 			},
 			func(t *testing.T) {
 				th.assertFileContent(filepath.Join("public", "sect1", "index.html"), "Base: sect")
@@ -109,7 +104,6 @@ func TestTemplateLookupOrder(t *testing.T) {
 				cfg.Set("theme", "mytheme")
 				writeSource(t, fs, filepath.Join("themes", "mytheme", "layouts", "section", "sect1-baseof.html"), `Base Theme: {{block "main" .}}block{{end}}`)
 				writeSource(t, fs, filepath.Join("layouts", "section", "sect1.html"), `{{define "main"}}sect{{ end }}`)
-
 			},
 			func(t *testing.T) {
 				th.assertFileContent(filepath.Join("public", "sect1", "index.html"), "Base Theme: sect")
@@ -123,7 +117,6 @@ func TestTemplateLookupOrder(t *testing.T) {
 				writeSource(t, fs, filepath.Join("themes", "mytheme", "layouts", "_default", "baseof.html"), `Base Theme: {{block "main" .}}block{{end}}`)
 				writeSource(t, fs, filepath.Join("themes", "mytheme", "layouts", "_default", "list.html"), `{{define "main"}}list{{ end }}`)
 				writeSource(t, fs, filepath.Join("themes", "mytheme", "layouts", "index.html"), `{{define "main"}}index{{ end }}`)
-
 			},
 			func(t *testing.T) {
 				th.assertFileContent(filepath.Join("public", "sect1", "index.html"), "Base: list")
@@ -136,7 +129,6 @@ func TestTemplateLookupOrder(t *testing.T) {
 				cfg.Set("theme", "mytheme")
 				writeSource(t, fs, filepath.Join("themes", "mytheme", "layouts", "_default", "baseof.html"), `Base Theme: {{block "main" .}}block{{end}}`)
 				writeSource(t, fs, filepath.Join("themes", "mytheme", "layouts", "_default", "list.html"), `{{define "main"}}list{{ end }}`)
-
 			},
 			func(t *testing.T) {
 				th.assertFileContent(filepath.Join("public", "sect1", "index.html"), "Base Theme: list")
@@ -158,7 +150,6 @@ func TestTemplateLookupOrder(t *testing.T) {
 
 				// sect2 with list template in /section
 				writeSource(t, fs, filepath.Join("themes", "mytheme", "layouts", "section", "sect2.html"), `sect2 list`)
-
 			},
 			func(t *testing.T) {
 				th.assertFileContent(filepath.Join("public", "sect1", "index.html"), "sect list")
@@ -170,7 +161,6 @@ func TestTemplateLookupOrder(t *testing.T) {
 			// Issue #2995
 			"Test section list and single template selection with base template",
 			func(t *testing.T) {
-
 				writeSource(t, fs, filepath.Join("layouts", "_default", "baseof.html"), `Base Default: {{block "main" .}}block{{end}}`)
 				writeSource(t, fs, filepath.Join("layouts", "sect1", "baseof.html"), `Base Sect1: {{block "main" .}}block{{end}}`)
 				writeSource(t, fs, filepath.Join("layouts", "section", "sect2-baseof.html"), `Base Sect2: {{block "main" .}}block{{end}}`)
@@ -183,7 +173,6 @@ func TestTemplateLookupOrder(t *testing.T) {
 
 				// sect2 with list template in /section
 				writeSource(t, fs, filepath.Join("layouts", "section", "sect2.html"), `{{define "main"}}sect2 list{{ end }}`)
-
 			},
 			func(t *testing.T) {
 				th.assertFileContent(filepath.Join("public", "sect1", "index.html"), "Base Sect1", "sect1 list")
@@ -214,7 +203,7 @@ Some content
 			this.setup(t)
 
 			buildSingleSite(t, deps.DepsCfg{Fs: fs, Cfg: cfg}, BuildCfg{})
-			//helpers.PrintFs(s.BaseFs.Layouts.Fs, "", os.Stdout)
+			// helpers.PrintFs(s.BaseFs.Layouts.Fs, "", os.Stdout)
 			this.assert(t)
 		})
 
@@ -223,7 +212,6 @@ Some content
 
 // https://github.com/gohugoio/hugo/issues/4895
 func TestTemplateBOM(t *testing.T) {
-
 	b := newTestSitesBuilder(t).WithSimpleConfigFile()
 	bom := "\ufeff"
 
@@ -242,7 +230,6 @@ Page Content
 	b.CreateSites().Build(BuildCfg{})
 
 	b.AssertFileContent("public/page/index.html", "Base: Hi!?")
-
 }
 
 func TestTemplateManyBaseTemplates(t *testing.T) {
@@ -278,7 +265,6 @@ Base %d: {{ block "main" . }}FOO{{ end }}
 		id := i + 1
 		b.AssertFileContent(fmt.Sprintf("public/page%d/index.html", id), fmt.Sprintf(`Base %d: %d`, id, id))
 	}
-
 }
 
 // https://github.com/gohugoio/hugo/issues/6790
@@ -315,7 +301,6 @@ title: The Page
 
 	b.AssertFileContent("public/blog/p1/index.html", `single`)
 	b.AssertFileContent("public/blog/index.html", `list`)
-
 }
 
 // https://github.com/gohugoio/hugo/issues/6816
@@ -336,7 +321,6 @@ func TestTemplateBaseWithComment(t *testing.T) {
 	b.Build(BuildCfg{})
 	b.AssertFileContent("public/index.html", `Base:
 Bonjour`)
-
 }
 
 func TestTemplateLookupSite(t *testing.T) {
@@ -389,13 +373,10 @@ title: My Page
 		b.AssertFileContent("public/fr/index.html", `Baseof fr: Main Home Fr`)
 		b.AssertFileContent("public/en/mysection/index.html", `Baseof mysection: Main Default List`)
 		b.AssertFileContent("public/en/mysection/p1/index.html", `Baseof mysection: Main Default Single`)
-
 	})
-
 }
 
 func TestTemplateFuncs(t *testing.T) {
-
 	b := newTestSitesBuilder(t).WithDefaultMultiSiteConfig()
 
 	homeTpl := `Site: {{ site.Language.Lang }} / {{ .Site.Language.Lang }} / {{ site.BaseURL }}
@@ -419,48 +400,79 @@ Hugo: {{ hugo.Generator }}
 		"Sites: en",
 		"Hugo: <meta name=\"generator\" content=\"Hugo",
 	)
-
 }
 
 func TestPartialWithReturn(t *testing.T) {
+	c := qt.New(t)
 
-	b := newTestSitesBuilder(t).WithSimpleConfigFile()
+	newBuilder := func(t testing.TB) *sitesBuilder {
+		b := newTestSitesBuilder(t).WithSimpleConfigFile()
+		b.WithTemplatesAdded(
+			"partials/add42.tpl", `
+		{{ $v := add . 42 }}
+		{{ return $v }}
+		`,
+			"partials/dollarContext.tpl", `
+{{ $v := add $ 42 }}
+{{ return $v }}
+`,
+			"partials/dict.tpl", `
+{{ $v := add $.adder 42 }}
+{{ return $v }}
+`,
+			"partials/complex.tpl", `
+{{ return add . 42 }}
+`, "partials/hello.tpl", `
+		{{ $v := printf "hello %s" . }}
+		{{ return $v }}
+		`,
+		)
 
-	b.WithTemplatesAdded(
-		"index.html", `
+		return b
+	}
+
+	c.Run("Return", func(c *qt.C) {
+		b := newBuilder(c)
+
+		b.WithTemplatesAdded(
+			"index.html", `
 Test Partials With Return Values:
 
 add42: 50: {{ partial "add42.tpl" 8 }}
+hello world: {{ partial "hello.tpl" "world" }}
 dollarContext: 60: {{ partial "dollarContext.tpl" 18 }}
 adder: 70: {{ partial "dict.tpl" (dict "adder" 28) }}
 complex: 80: {{ partial "complex.tpl" 38 }}
 `,
-		"partials/add42.tpl", `
-		{{ $v := add . 42 }}
-		{{ return $v }}
-		`,
-		"partials/dollarContext.tpl", `
-{{ $v := add $ 42 }}
-{{ return $v }}
-`,
-		"partials/dict.tpl", `
-{{ $v := add $.adder 42 }}
-{{ return $v }}
-`,
-		"partials/complex.tpl", `
-{{ return add . 42 }}
-`,
-	)
+		)
 
-	b.CreateSites().Build(BuildCfg{})
+		b.CreateSites().Build(BuildCfg{})
 
-	b.AssertFileContent("public/index.html",
-		"add42: 50: 50",
-		"dollarContext: 60: 60",
-		"adder: 70: 70",
-		"complex: 80: 80",
-	)
+		b.AssertFileContent("public/index.html", `
+add42: 50: 50
+hello world: hello world
+dollarContext: 60: 60
+adder: 70: 70
+complex: 80: 80
+`,
+		)
+	})
 
+	c.Run("Zero argument", func(c *qt.C) {
+		b := newBuilder(c)
+
+		b.WithTemplatesAdded(
+			"index.html", `
+Test Partials With Return Values:
+
+add42: fail: {{ partial "add42.tpl" 0 }}
+
+`,
+		)
+
+		e := b.CreateSites().BuildE(BuildCfg{})
+		b.Assert(e, qt.Not(qt.IsNil))
+	})
 }
 
 func TestPartialCached(t *testing.T) {
@@ -562,8 +574,7 @@ title: P1
 
 	idset := make(map[identity.Identity]bool)
 	collectIdentities(idset, templ.(tpl.Info))
-	b.Assert(idset, qt.HasLen, 10)
-
+	b.Assert(idset, qt.HasLen, 11)
 }
 
 func TestTemplateGoIssues(t *testing.T) {
@@ -599,7 +610,6 @@ func ident(level int) string {
 }
 
 func TestPartialInline(t *testing.T) {
-
 	b := newTestSitesBuilder(t)
 
 	b.WithContent("p1.md", "")
@@ -631,11 +641,9 @@ P2: {{ $p2 }}
 P1: Inline: p1
 P2: 32`,
 	)
-
 }
 
 func TestPartialInlineBase(t *testing.T) {
-
 	b := newTestSitesBuilder(t)
 
 	b.WithContent("p1.md", "")
@@ -675,5 +683,45 @@ P2: 32
 P3: Inline: p3
 `,
 	)
+}
 
+// https://github.com/gohugoio/hugo/issues/7478
+func TestBaseWithAndWithoutDefine(t *testing.T) {
+	b := newTestSitesBuilder(t)
+
+	b.WithContent("p1.md", "---\ntitle: P\n---\nContent")
+
+	b.WithTemplates(
+		"_default/baseof.html", `
+::Header Start:{{ block "header" . }}{{ end }}:Header End:
+::{{ block "main" . }}Main{{ end }}::
+`, "index.html", `
+{{ define "header" }}
+Home Header
+{{ end }}
+{{ define "main" }}
+This is home main
+{{ end }}
+`,
+
+		"_default/single.html", `
+{{ define "main" }}
+This is single main
+{{ end }}
+`,
+	)
+
+	b.CreateSites().Build(BuildCfg{})
+
+	b.AssertFileContent("public/index.html", `
+Home Header
+This is home main
+`,
+	)
+
+	b.AssertFileContent("public/p1/index.html", `
+ ::Header Start::Header End:
+This is single main
+`,
+	)
 }
