@@ -18,9 +18,12 @@ package asciidocext
 
 import (
 	"bytes"
-	"os/exec"
 	"path/filepath"
 
+	"github.com/gohugoio/hugo/htesting"
+
+	"github.com/cli/safeexec"
+
 	"github.com/gohugoio/hugo/identity"
 	"github.com/gohugoio/hugo/markup/asciidocext/asciidocext_config"
 	"github.com/gohugoio/hugo/markup/converter"
@@ -82,7 +85,7 @@ func (a *asciidocConverter) Supports(_ identity.Identity) bool {
 func (a *asciidocConverter) getAsciidocContent(src []byte, ctx converter.DocumentContext) []byte {
 	path := getAsciidoctorExecPath()
 	if path == "" {
-		a.cfg.Logger.ERROR.Println("asciidoctor not found in $PATH: Please install.\n",
+		a.cfg.Logger.Errorln("asciidoctor not found in $PATH: Please install.\n",
 			"                 Leaving AsciiDoc content unrendered.")
 		return src
 	}
@@ -90,20 +93,20 @@ func (a *asciidocConverter) getAsciidocContent(src []byte, ctx converter.Documen
 	args := a.parseArgs(ctx)
 	args = append(args, "-")
 
-	a.cfg.Logger.INFO.Println("Rendering", ctx.DocumentName, "with", path, "using asciidoctor args", args, "...")
+	a.cfg.Logger.Infoln("Rendering", ctx.DocumentName, "with", path, "using asciidoctor args", args, "...")
 
 	return internal.ExternallyRenderContent(a.cfg, ctx, src, path, args)
 }
 
 func (a *asciidocConverter) parseArgs(ctx converter.DocumentContext) []string {
-	var cfg = a.cfg.MarkupConfig.AsciidocExt
+	cfg := a.cfg.MarkupConfig.AsciidocExt
 	args := []string{}
 
 	args = a.appendArg(args, "-b", cfg.Backend, asciidocext_config.CliDefault.Backend, asciidocext_config.AllowedBackend)
 
 	for _, extension := range cfg.Extensions {
 		if !asciidocext_config.AllowedExtensions[extension] {
-			a.cfg.Logger.ERROR.Println("Unsupported asciidoctor extension was passed in. Extension `" + extension + "` ignored.")
+			a.cfg.Logger.Errorln("Unsupported asciidoctor extension was passed in. Extension `" + extension + "` ignored.")
 			continue
 		}
 
@@ -112,7 +115,7 @@ func (a *asciidocConverter) parseArgs(ctx converter.DocumentContext) []string {
 
 	for attributeKey, attributeValue := range cfg.Attributes {
 		if asciidocext_config.DisallowedAttributes[attributeKey] {
-			a.cfg.Logger.ERROR.Println("Unsupported asciidoctor attribute was passed in. Attribute `" + attributeKey + "` ignored.")
+			a.cfg.Logger.Errorln("Unsupported asciidoctor attribute was passed in. Attribute `" + attributeKey + "` ignored.")
 			continue
 		}
 
@@ -125,7 +128,7 @@ func (a *asciidocConverter) parseArgs(ctx converter.DocumentContext) []string {
 		destinationDir := a.cfg.Cfg.GetString("destination")
 
 		if destinationDir == "" {
-			a.cfg.Logger.ERROR.Println("markup.asciidocext.workingFolderCurrent requires hugo command option --destination to be set")
+			a.cfg.Logger.Errorln("markup.asciidocext.workingFolderCurrent requires hugo command option --destination to be set")
 		}
 		if !filepath.IsAbs(destinationDir) && sourceDir != "" {
 			destinationDir = filepath.Join(sourceDir, destinationDir)
@@ -137,21 +140,20 @@ func (a *asciidocConverter) parseArgs(ctx converter.DocumentContext) []string {
 		file := filepath.Base(ctx.Filename)
 		if a.cfg.Cfg.GetBool("uglyUrls") || file == "_index.adoc" || file == "index.adoc" {
 			outDir, err = filepath.Abs(filepath.Dir(filepath.Join(destinationDir, ctx.DocumentName)))
-
 		} else {
 			postDir := ""
 			page, ok := ctx.Document.(pageSubset)
 			if ok {
 				postDir = filepath.Base(page.RelPermalink())
 			} else {
-				a.cfg.Logger.ERROR.Println("unable to cast interface to pageSubset")
+				a.cfg.Logger.Errorln("unable to cast interface to pageSubset")
 			}
 
 			outDir, err = filepath.Abs(filepath.Join(destinationDir, filepath.Dir(ctx.DocumentName), postDir))
 		}
 
 		if err != nil {
-			a.cfg.Logger.ERROR.Println("asciidoctor outDir: ", err)
+			a.cfg.Logger.Errorln("asciidoctor outDir: ", err)
 		}
 
 		args = append(args, "--base-dir", contentDir, "-a", "outdir="+outDir)
@@ -160,7 +162,7 @@ func (a *asciidocConverter) parseArgs(ctx converter.DocumentContext) []string {
 	if cfg.NoHeaderOrFooter {
 		args = append(args, "--no-header-footer")
 	} else {
-		a.cfg.Logger.WARN.Println("asciidoctor parameter NoHeaderOrFooter is expected for correct html rendering")
+		a.cfg.Logger.Warnln("asciidoctor parameter NoHeaderOrFooter is expected for correct html rendering")
 	}
 
 	if cfg.SectionNumbers {
@@ -187,14 +189,14 @@ func (a *asciidocConverter) appendArg(args []string, option, value, defaultValue
 		if allowedValues[value] {
 			args = append(args, option, value)
 		} else {
-			a.cfg.Logger.ERROR.Println("Unsupported asciidoctor value `" + value + "` for option " + option + " was passed in and will be ignored.")
+			a.cfg.Logger.Errorln("Unsupported asciidoctor value `" + value + "` for option " + option + " was passed in and will be ignored.")
 		}
 	}
 	return args
 }
 
 func getAsciidoctorExecPath() string {
-	path, err := exec.LookPath("asciidoctor")
+	path, err := safeexec.LookPath("asciidoctor")
 	if err != nil {
 		return ""
 	}
@@ -309,5 +311,8 @@ func nodeContent(node *html.Node) string {
 
 // Supports returns whether Asciidoctor is installed on this computer.
 func Supports() bool {
+	if htesting.SupportsAll() {
+		return true
+	}
 	return getAsciidoctorExecPath() != ""
 }
