@@ -17,19 +17,19 @@ package goldmark
 import (
 	"bytes"
 	"fmt"
+	"math/bits"
 	"path/filepath"
 	"runtime/debug"
 
+	"github.com/gohugoio/hugo/identity"
+
 	"github.com/pkg/errors"
 
 	"github.com/spf13/afero"
 
 	"github.com/gohugoio/hugo/hugofs"
-
-	"github.com/alecthomas/chroma/styles"
 	"github.com/gohugoio/hugo/markup/converter"
 	"github.com/gohugoio/hugo/markup/highlight"
-	"github.com/gohugoio/hugo/markup/markup_config"
 	"github.com/gohugoio/hugo/markup/tableofcontents"
 	"github.com/yuin/goldmark"
 	hl "github.com/yuin/goldmark-highlighting"
@@ -48,32 +48,38 @@ type provide struct {
 }
 
 func (p provide) New(cfg converter.ProviderConfig) (converter.Provider, error) {
-	md := newMarkdown(cfg.MarkupConfig)
+	md := newMarkdown(cfg)
+
 	return converter.NewProvider("goldmark", func(ctx converter.DocumentContext) (converter.Converter, error) {
 		return &goldmarkConverter{
 			ctx: ctx,
 			cfg: cfg,
 			md:  md,
+			sanitizeAnchorName: func(s string) string {
+				return sanitizeAnchorNameString(s, cfg.MarkupConfig.Goldmark.Parser.AutoHeadingIDType)
+			},
 		}, nil
 	}), nil
 }
 
+var _ converter.AnchorNameSanitizer = (*goldmarkConverter)(nil)
+
 type goldmarkConverter struct {
 	md  goldmark.Markdown
 	ctx converter.DocumentContext
 	cfg converter.ProviderConfig
+
+	sanitizeAnchorName func(s string) string
 }
 
-func newMarkdown(mcfg markup_config.Config) goldmark.Markdown {
-	cfg := mcfg.Goldmark
+func (c *goldmarkConverter) SanitizeAnchorName(s string) string {
+	return c.sanitizeAnchorName(s)
+}
 
-	var (
-		extensions = []goldmark.Extender{
-			newTocExtension(),
-		}
-		rendererOptions []renderer.Option
-		parserOptions   []parser.Option
-	)
+func newMarkdown(pcfg converter.ProviderConfig) goldmark.Markdown {
+	mcfg := pcfg.MarkupConfig
+	cfg := pcfg.MarkupConfig.Goldmark
+	var rendererOptions []renderer.Option
 
 	if cfg.Renderer.HardWraps {
 		rendererOptions = append(rendererOptions, html.WithHardWraps())
@@ -87,6 +93,14 @@ func newMarkdown(mcfg markup_config.Config) goldmark.Markdown {
 		rendererOptions = append(rendererOptions, html.WithUnsafe())
 	}
 
+	var (
+		extensions = []goldmark.Extender{
+			newLinks(),
+			newTocExtension(rendererOptions),
+		}
+		parserOptions []parser.Option
+	)
+
 	if mcfg.Highlight.CodeFences {
 		extensions = append(extensions, newHighlighting(mcfg.Highlight))
 	}
@@ -140,18 +154,74 @@ func newMarkdown(mcfg markup_config.Config) goldmark.Markdown {
 	)
 
 	return md
-
 }
 
+var _ identity.IdentitiesProvider = (*converterResult)(nil)
+
 type converterResult struct {
 	converter.Result
 	toc tableofcontents.Root
+	ids identity.Identities
 }
 
 func (c converterResult) TableOfContents() tableofcontents.Root {
 	return c.toc
 }
 
+func (c converterResult) GetIdentities() identity.Identities {
+	return c.ids
+}
+
+type bufWriter struct {
+	*bytes.Buffer
+}
+
+const maxInt = 1<<(bits.UintSize-1) - 1
+
+func (b *bufWriter) Available() int {
+	return maxInt
+}
+
+func (b *bufWriter) Buffered() int {
+	return b.Len()
+}
+
+func (b *bufWriter) Flush() error {
+	return nil
+}
+
+type renderContext struct {
+	*bufWriter
+	pos int
+	renderContextData
+}
+
+type renderContextData interface {
+	RenderContext() converter.RenderContext
+	DocumentContext() converter.DocumentContext
+	AddIdentity(id identity.Provider)
+}
+
+type renderContextDataHolder struct {
+	rctx converter.RenderContext
+	dctx converter.DocumentContext
+	ids  identity.Manager
+}
+
+func (ctx *renderContextDataHolder) RenderContext() converter.RenderContext {
+	return ctx.rctx
+}
+
+func (ctx *renderContextDataHolder) DocumentContext() converter.DocumentContext {
+	return ctx.dctx
+}
+
+func (ctx *renderContextDataHolder) AddIdentity(id identity.Provider) {
+	ctx.ids.Add(id)
+}
+
+var converterIdentity = identity.KeyValueIdentity{Key: "goldmark", Value: "converter"}
+
 func (c *goldmarkConverter) Convert(ctx converter.RenderContext) (result converter.Result, err error) {
 	defer func() {
 		if r := recover(); r != nil {
@@ -164,11 +234,9 @@ func (c *goldmarkConverter) Convert(ctx converter.RenderContext) (result convert
 		}
 	}()
 
-	buf := &bytes.Buffer{}
+	buf := &bufWriter{Buffer: &bytes.Buffer{}}
 	result = buf
-	pctx := parser.NewContext()
-	pctx.Set(tocEnableKey, ctx.RenderTOC)
-
+	pctx := c.newParserContext(ctx)
 	reader := text.NewReader(ctx.Src)
 
 	doc := c.md.Parser().Parse(
@@ -176,27 +244,57 @@ func (c *goldmarkConverter) Convert(ctx converter.RenderContext) (result convert
 		parser.WithContext(pctx),
 	)
 
-	if err := c.md.Renderer().Render(buf, ctx.Src, doc); err != nil {
+	rcx := &renderContextDataHolder{
+		rctx: ctx,
+		dctx: c.ctx,
+		ids:  identity.NewManager(converterIdentity),
+	}
+
+	w := &renderContext{
+		bufWriter:         buf,
+		renderContextData: rcx,
+	}
+
+	if err := c.md.Renderer().Render(w, ctx.Src, doc); err != nil {
 		return nil, err
 	}
 
-	if toc, ok := pctx.Get(tocResultKey).(tableofcontents.Root); ok {
-		return converterResult{
-			Result: buf,
-			toc:    toc,
-		}, nil
-	}
+	return converterResult{
+		Result: buf,
+		ids:    rcx.ids.GetIdentities(),
+		toc:    pctx.TableOfContents(),
+	}, nil
+}
 
-	return buf, nil
+var featureSet = map[identity.Identity]bool{
+	converter.FeatureRenderHooks: true,
+}
+
+func (c *goldmarkConverter) Supports(feature identity.Identity) bool {
+	return featureSet[feature.GetIdentity()]
+}
+
+func (c *goldmarkConverter) newParserContext(rctx converter.RenderContext) *parserContext {
+	ctx := parser.NewContext(parser.WithIDs(newIDFactory(c.cfg.MarkupConfig.Goldmark.Parser.AutoHeadingIDType)))
+	ctx.Set(tocEnableKey, rctx.RenderTOC)
+	return &parserContext{
+		Context: ctx,
+	}
+}
+
+type parserContext struct {
+	parser.Context
+}
+
+func (p *parserContext) TableOfContents() tableofcontents.Root {
+	if v := p.Get(tocResultKey); v != nil {
+		return v.(tableofcontents.Root)
+	}
+	return tableofcontents.Root{}
 }
 
 func newHighlighting(cfg highlight.Config) goldmark.Extender {
-	style := styles.Get(cfg.Style)
-	if style == nil {
-		style = styles.Fallback
-	}
-
-	e := hl.NewHighlighting(
+	return hl.NewHighlighting(
 		hl.WithStyle(cfg.Style),
 		hl.WithGuessLanguage(cfg.GuessSyntax),
 		hl.WithCodeBlockOptions(highlight.GetCodeBlockOptions()),
@@ -227,9 +325,6 @@ func newHighlighting(cfg highlight.Config) goldmark.Extender {
 			}
 
 			w.WriteString("</div>")
-
 		}),
 	)
-
-	return e
 }
