@@ -31,7 +31,6 @@ import (
 )
 
 func convert(c *qt.C, mconf markup_config.Config, content string) converter.Result {
-
 	p, err := Provider.New(
 		converter.ProviderConfig{
 			MarkupConfig: mconf,
@@ -163,7 +162,6 @@ description
 	c.Assert(ok, qt.Equals, true)
 	tocHTML := toc.TableOfContents().ToHTML(1, 2, false)
 	c.Assert(tocHTML, qt.Contains, "TableOfContents")
-
 }
 
 func TestConvertAutoIDAsciiOnly(t *testing.T) {
@@ -195,6 +193,25 @@ func TestConvertAutoIDBlackfriday(t *testing.T) {
 	c.Assert(got, qt.Contains, "<h2 id=\"let-s-try-this-shall-we\">")
 }
 
+func TestConvertIssues(t *testing.T) {
+	c := qt.New(t)
+
+	// https://github.com/gohugoio/hugo/issues/7619
+	c.Run("Hyphen in HTML attributes", func(c *qt.C) {
+		mconf := markup_config.Default
+		mconf.Goldmark.Renderer.Unsafe = true
+		input := `<custom-element>
+    <div>This will be "slotted" into the custom element.</div>
+</custom-element>
+`
+
+		b := convert(c, mconf, input)
+		got := string(b.Bytes())
+
+		c.Assert(got, qt.Contains, "<custom-element>\n    <div>This will be \"slotted\" into the custom element.</div>\n</custom-element>\n")
+	})
+}
+
 func TestCodeFence(t *testing.T) {
 	c := qt.New(t)
 
@@ -237,7 +254,6 @@ LINE5
 </code></pre></div>`)
 		result = convertForConfig(c, cfg, `echo "Hugo Rocks!"`, "unknown")
 		c.Assert(result, qt.Equals, "<pre><code class=\"language-unknown\" data-lang=\"unknown\">echo &quot;Hugo Rocks!&quot;\n</code></pre>")
-
 	})
 
 	c.Run("Highlight lines, default config", func(c *qt.C) {
