@@ -16,9 +16,11 @@ package rst
 
 import (
 	"bytes"
-	"os/exec"
 	"runtime"
 
+	"github.com/cli/safeexec"
+	"github.com/gohugoio/hugo/htesting"
+
 	"github.com/gohugoio/hugo/identity"
 	"github.com/gohugoio/hugo/markup/internal"
 
@@ -60,11 +62,11 @@ func (c *rstConverter) getRstContent(src []byte, ctx converter.DocumentContext)
 	path := getRstExecPath()
 
 	if path == "" {
-		logger.ERROR.Println("rst2html / rst2html.py not found in $PATH: Please install.\n",
+		logger.Println("rst2html / rst2html.py not found in $PATH: Please install.\n",
 			"                 Leaving reStructuredText content unrendered.")
 		return src
 	}
-	logger.INFO.Println("Rendering", ctx.DocumentName, "with", path, "...")
+	logger.Println("Rendering", ctx.DocumentName, "with", path, "...")
 	var result []byte
 	// certain *nix based OSs wrap executables in scripted launchers
 	// invoking binaries on these OSs via python interpreter causes SyntaxError
@@ -81,7 +83,7 @@ func (c *rstConverter) getRstContent(src []byte, ctx converter.DocumentContext)
 	// TODO(bep) check if rst2html has a body only option.
 	bodyStart := bytes.Index(result, []byte("<body>\n"))
 	if bodyStart < 0 {
-		bodyStart = -7 //compensate for length
+		bodyStart = -7 // compensate for length
 	}
 
 	bodyEnd := bytes.Index(result, []byte("\n</body>"))
@@ -96,9 +98,9 @@ func (c *rstConverter) getRstContent(src []byte, ctx converter.DocumentContext)
 }
 
 func getRstExecPath() string {
-	path, err := exec.LookPath("rst2html")
+	path, err := safeexec.LookPath("rst2html")
 	if err != nil {
-		path, err = exec.LookPath("rst2html.py")
+		path, err = safeexec.LookPath("rst2html.py")
 		if err != nil {
 			return ""
 		}
@@ -108,5 +110,8 @@ func getRstExecPath() string {
 
 // Supports returns whether rst is installed on this computer.
 func Supports() bool {
+	if htesting.SupportsAll() {
+		return true
+	}
 	return getRstExecPath() != ""
 }
