@@ -18,6 +18,7 @@ import (
 	"fmt"
 	"os"
 	"path/filepath"
+	"regexp"
 	"strings"
 	"time"
 
@@ -109,7 +110,6 @@ func (h *Client) collect(tidy bool) (ModulesConfig, *collector) {
 		AllModules:        c.modules,
 		GoModulesFilename: c.GoModulesFilename,
 	}, c
-
 }
 
 type ModulesConfig struct {
@@ -123,11 +123,11 @@ type ModulesConfig struct {
 	GoModulesFilename string
 }
 
-func (m *ModulesConfig) setActiveMods(logger *loggers.Logger) error {
+func (m *ModulesConfig) setActiveMods(logger loggers.Logger) error {
 	var activeMods Modules
 	for _, mod := range m.AllModules {
 		if !mod.Config().HugoVersion.IsValid() {
-			logger.WARN.Printf(`Module %q is not compatible with this Hugo version; run "hugo mod graph" for more information.`, mod.Path())
+			logger.Warnf(`Module %q is not compatible with this Hugo version; run "hugo mod graph" for more information.`, mod.Path())
 		}
 		if !mod.Disabled() {
 			activeMods = append(activeMods, mod)
@@ -139,7 +139,7 @@ func (m *ModulesConfig) setActiveMods(logger *loggers.Logger) error {
 	return nil
 }
 
-func (m *ModulesConfig) finalize(logger *loggers.Logger) error {
+func (m *ModulesConfig) finalize(logger loggers.Logger) error {
 	for _, mod := range m.AllModules {
 		m := mod.(*moduleAdapter)
 		m.mounts = filterUnwantedMounts(m.mounts)
@@ -196,7 +196,8 @@ func (c *collector) initModules() error {
 		gomods:   goModules{},
 	}
 
-	if !c.ccfg.IgnoreVendor && c.isVendored(c.ccfg.WorkingDir) {
+	// If both these are true, we don't even need Go installed to build.
+	if c.ccfg.IgnoreVendor == nil && c.isVendored(c.ccfg.WorkingDir) {
 		return nil
 	}
 
@@ -229,7 +230,7 @@ func (c *collector) add(owner *moduleAdapter, moduleImport Import, disabled bool
 	modulePath := moduleImport.Path
 	var realOwner Module = owner
 
-	if !c.ccfg.IgnoreVendor {
+	if !c.ccfg.shouldIgnoreVendor(modulePath) {
 		if err := c.collectModulesTXT(owner); err != nil {
 			return nil, err
 		}
@@ -272,10 +273,14 @@ func (c *collector) add(owner *moduleAdapter, moduleImport Import, disabled bool
 				}
 			}
 
-			// Fall back to /themes/<mymodule>
+			// Fall back to project/themes/<mymodule>
 			if moduleDir == "" {
-				moduleDir = filepath.Join(c.ccfg.ThemesDir, modulePath)
-
+				var err error
+				moduleDir, err = c.createThemeDirname(modulePath, owner.projectMod)
+				if err != nil {
+					c.err = err
+					return nil, nil
+				}
 				if found, _ := afero.Exists(c.fs, moduleDir); !found {
 					c.err = c.wrapModuleNotFound(errors.Errorf(`module %q not found; either add it as a Hugo Module or store it in %q.`, modulePath, c.ccfg.ThemesDir))
 					return nil, nil
@@ -319,7 +324,6 @@ func (c *collector) add(owner *moduleAdapter, moduleImport Import, disabled bool
 
 	c.modules = append(c.modules, ma)
 	return ma, nil
-
 }
 
 func (c *collector) addAndRecurse(owner *moduleAdapter, disabled bool) error {
@@ -338,7 +342,7 @@ func (c *collector) addAndRecurse(owner *moduleAdapter, disabled bool) error {
 			if err != nil {
 				return err
 			}
-			if tc == nil {
+			if tc == nil || moduleImport.IgnoreImports {
 				continue
 			}
 			if err := c.addAndRecurse(tc, disabled); err != nil {
@@ -357,7 +361,6 @@ func (c *collector) applyMounts(moduleImport Import, mod *moduleAdapter) error {
 	if len(mounts) == 0 {
 		// Mounts not defined by the import.
 		mounts = modConfig.Mounts
-
 	}
 
 	if !mod.projectMod && len(mounts) == 0 {
@@ -381,12 +384,16 @@ func (c *collector) applyMounts(moduleImport Import, mod *moduleAdapter) error {
 		return err
 	}
 
+	mounts, err = c.mountCommonJSConfig(mod, mounts)
+	if err != nil {
+		return err
+	}
+
 	mod.mounts = mounts
 	return nil
 }
 
 func (c *collector) applyThemeConfig(tc *moduleAdapter) error {
-
 	var (
 		configFilename string
 		cfg            config.Provider
@@ -415,7 +422,7 @@ func (c *collector) applyThemeConfig(tc *moduleAdapter) error {
 		}
 		themeCfg, err = metadecoders.Default.UnmarshalToMap(data, metadecoders.TOML)
 		if err != nil {
-			c.logger.WARN.Printf("Failed to read module config for %q in %q: %s", tc.Path(), themeTOML, err)
+			c.logger.Warnf("Failed to read module config for %q in %q: %s", tc.Path(), themeTOML, err)
 		} else {
 			maps.ToLower(themeCfg)
 		}
@@ -434,7 +441,7 @@ func (c *collector) applyThemeConfig(tc *moduleAdapter) error {
 		tc.cfg = cfg
 	}
 
-	config, err := DecodeConfig(cfg)
+	config, err := decodeConfig(cfg, c.moduleConfig.replacementsMap)
 	if err != nil {
 		return err
 	}
@@ -466,14 +473,13 @@ func (c *collector) applyThemeConfig(tc *moduleAdapter) error {
 	tc.config = config
 
 	return nil
-
 }
 
 func (c *collector) collect() {
 	defer c.logger.PrintTimerIfDelayed(time.Now(), "hugo: collected modules")
 	d := debounce.New(2 * time.Second)
 	d(func() {
-		c.logger.FEEDBACK.Println("hugo: downloading modules …")
+		c.logger.Println("hugo: downloading modules …")
 	})
 	defer d(func() {})
 
@@ -491,7 +497,6 @@ func (c *collector) collect() {
 
 	// Add the project mod on top.
 	c.modules = append(Modules{projectMod}, c.modules...)
-
 }
 
 func (c *collector) isVendored(dir string) bool {
@@ -504,7 +509,6 @@ func (c *collector) collectModulesTXT(owner Module) error {
 	filename := filepath.Join(vendorDir, vendorModulesFilename)
 
 	f, err := c.fs.Open(filename)
-
 	if err != nil {
 		if os.IsNotExist(err) {
 			return nil
@@ -548,6 +552,43 @@ func (c *collector) loadModules() error {
 	return nil
 }
 
+// Matches postcss.config.js etc.
+var commonJSConfigs = regexp.MustCompile(`(babel|postcss|tailwind)\.config\.js`)
+
+func (c *collector) mountCommonJSConfig(owner *moduleAdapter, mounts []Mount) ([]Mount, error) {
+	for _, m := range mounts {
+		if strings.HasPrefix(m.Target, files.JsConfigFolderMountPrefix) {
+			// This follows the convention of the other component types (assets, content, etc.),
+			// if one or more is specified by the user, we skip the defaults.
+			// These mounts were added to Hugo in 0.75.
+			return mounts, nil
+		}
+	}
+
+	// Mount the common JS config files.
+	fis, err := afero.ReadDir(c.fs, owner.Dir())
+	if err != nil {
+		return mounts, err
+	}
+
+	for _, fi := range fis {
+		n := fi.Name()
+
+		should := n == files.FilenamePackageHugoJSON || n == files.FilenamePackageJSON
+		should = should || commonJSConfigs.MatchString(n)
+
+		if should {
+			mounts = append(mounts, Mount{
+				Source: n,
+				Target: filepath.Join(files.ComponentFolderAssets, files.FolderJSConfig, n),
+			})
+		}
+
+	}
+
+	return mounts, nil
+}
+
 func (c *collector) normalizeMounts(owner *moduleAdapter, mounts []Mount) ([]Mount, error) {
 	var out []Mount
 	dir := owner.Dir()
@@ -561,7 +602,6 @@ func (c *collector) normalizeMounts(owner *moduleAdapter, mounts []Mount) ([]Mou
 
 		mnt.Source = filepath.Clean(mnt.Source)
 		mnt.Target = filepath.Clean(mnt.Target)
-
 		var sourceDir string
 
 		if owner.projectMod && filepath.IsAbs(mnt.Source) {
@@ -609,7 +649,6 @@ func (c *collector) wrapModuleNotFound(err error) error {
 	}
 
 	return err
-
 }
 
 type vendoredModule struct {
@@ -632,7 +671,6 @@ func createProjectModule(gomod *goModule, workingDir string, conf Config) *modul
 		projectMod: true,
 		config:     conf,
 	}
-
 }
 
 // In the first iteration of Hugo Modules, we do not support multiple
