@@ -14,15 +14,14 @@
 package publisher
 
 import (
-	"regexp"
-
-	"github.com/gohugoio/hugo/helpers"
-	"golang.org/x/net/html"
-
 	"bytes"
+	"regexp"
 	"sort"
 	"strings"
 	"sync"
+
+	"github.com/gohugoio/hugo/helpers"
+	"golang.org/x/net/html"
 )
 
 func newHTMLElementsCollector() *htmlElementsCollector {
@@ -52,7 +51,6 @@ func (h *HTMLElements) Merge(other HTMLElements) {
 	h.Tags = helpers.UniqueStringsReuse(h.Tags)
 	h.Classes = helpers.UniqueStringsReuse(h.Classes)
 	h.IDs = helpers.UniqueStringsReuse(h.IDs)
-
 }
 
 func (h *HTMLElements) Sort() {
@@ -67,7 +65,9 @@ type cssClassCollectorWriter struct {
 
 	isCollecting bool
 	dropValue    bool
-	inQuote      bool
+
+	inQuote    bool
+	quoteValue byte
 }
 
 func (w *cssClassCollectorWriter) Write(p []byte) (n int, err error) {
@@ -120,12 +120,14 @@ func (w *cssClassCollectorWriter) Write(p []byte) (n int, err error) {
 						continue
 					}
 
+					key := s
+
 					s, tagName := w.insertStandinHTMLElement(s)
 					el := parseHTMLElement(s)
 					el.Tag = tagName
 
 					w.collector.mu.Lock()
-					w.collector.elementSet[s] = true
+					w.collector.elementSet[key] = true
 					if el.Tag != "" {
 						w.collector.elements = append(w.collector.elements, el)
 					}
@@ -138,7 +140,7 @@ func (w *cssClassCollectorWriter) Write(p []byte) (n int, err error) {
 	return
 }
 
-// The net/html parser does not handle single table elemnts as input, e.g. tbody.
+// The net/html parser does not handle single table elements as input, e.g. tbody.
 // We only care about the element/class/ids, so just store away the original tag name
 // and pretend it's a <div>.
 func (c *cssClassCollectorWriter) insertStandinHTMLElement(el string) (string, string) {
@@ -149,7 +151,6 @@ func (c *cssClassCollectorWriter) insertStandinHTMLElement(el string) (string, s
 	}
 	newv := strings.Replace(el, tag, "div", 1)
 	return newv, strings.ToLower(tag)
-
 }
 
 func (c *cssClassCollectorWriter) endCollecting(drop bool) {
@@ -165,7 +166,12 @@ func (c *cssClassCollectorWriter) startCollecting() {
 
 func (c *cssClassCollectorWriter) toggleIfQuote(b byte) {
 	if isQuote(b) {
-		c.inQuote = !c.inQuote
+		if c.inQuote && b == c.quoteValue {
+			c.inQuote = false
+		} else if !c.inQuote {
+			c.inQuote = true
+			c.quoteValue = b
+		}
 	}
 }
 
@@ -187,7 +193,6 @@ type htmlElementsCollector struct {
 }
 
 func (c *htmlElementsCollector) getHTMLElements() HTMLElements {
-
 	var (
 		classes []string
 		ids     []string
