@@ -175,7 +175,6 @@ func writeReleaseNotes(version string, infosMain, infosDocs gitInfos, to io.Writ
 	}
 
 	return nil
-
 }
 
 func fetchThemeCount() (int, error) {
@@ -235,16 +234,12 @@ func (r *ReleaseHandler) releaseNotesState(version string) (releaseNotesState, e
 	}
 
 	return releaseNotesNone, nil
-
 }
 
 func (r *ReleaseHandler) writeReleaseNotesToTemp(version string, isPatch bool, infosMain, infosDocs gitInfos) (string, error) {
-
 	docsTempPath, name := getReleaseNotesDocsTempDirAndName(version, isPatch)
 
-	var (
-		w io.WriteCloser
-	)
+	var w io.WriteCloser
 
 	if !r.try {
 		os.Mkdir(docsTempPath, os.ModePerm)
@@ -269,7 +264,6 @@ func (r *ReleaseHandler) writeReleaseNotesToTemp(version string, isPatch bool, i
 	}
 
 	return name, nil
-
 }
 
 func (r *ReleaseHandler) writeReleaseNotesToDocs(title, description, sourceFilename string) (string, error) {
@@ -324,5 +318,4 @@ categories: ["Releases"]%s
 	}
 
 	return targetFullFilename, nil
-
 }
