@@ -354,7 +354,7 @@ func TestImageResizeInSubPath(t *testing.T) {
 	assertImageFile(c, spec.BaseFs.PublishFs, publishedImageFilename, 101, 101)
 	c.Assert(spec.BaseFs.PublishFs.Remove(publishedImageFilename), qt.IsNil)
 
-	// Cleare mem cache to simulate reading from the file cache.
+	// Clear mem cache to simulate reading from the file cache.
 	spec.imageCache.clear()
 
 	resizedAgain, err := image.Resize("101x101")
@@ -413,11 +413,9 @@ func TestImageExif(t *testing.T) {
 	image = fetchResourceForSpec(spec, c, "sunset.jpg").(resource.Image)
 	// This will read from file cache.
 	getAndCheckExif(c, image)
-
 }
 
 func BenchmarkImageExif(b *testing.B) {
-
 	getImages := func(c *qt.C, b *testing.B, fs afero.Fs) []resource.Image {
 		spec := newTestResourceSpec(specDescriptor{fs: fs, c: c})
 		images := make([]resource.Image, b.N)
@@ -431,7 +429,6 @@ func BenchmarkImageExif(b *testing.B) {
 		x := image.Exif()
 		c.Assert(x, qt.Not(qt.IsNil))
 		c.Assert(x.Long, qt.Equals, float64(-4.50846))
-
 	}
 
 	b.Run("Cold cache", func(b *testing.B) {
@@ -443,7 +440,6 @@ func BenchmarkImageExif(b *testing.B) {
 		for i := 0; i < b.N; i++ {
 			getAndCheckExif(c, images[i])
 		}
-
 	})
 
 	b.Run("Cold cache, 10", func(b *testing.B) {
@@ -457,7 +453,6 @@ func BenchmarkImageExif(b *testing.B) {
 				getAndCheckExif(c, images[i])
 			}
 		}
-
 	})
 
 	b.Run("Warm cache", func(b *testing.B) {
@@ -475,9 +470,7 @@ func BenchmarkImageExif(b *testing.B) {
 		for i := 0; i < b.N; i++ {
 			getAndCheckExif(c, images[i])
 		}
-
 	})
-
 }
 
 // usesFMA indicates whether "fused multiply and add" (FMA) instruction is
@@ -540,6 +533,11 @@ func TestImageOperationsGolden(t *testing.T) {
 		fmt.Println(workDir)
 	}
 
+	gopher := fetchImageForSpec(spec, c, "gopher-hero8.png")
+	var err error
+	gopher, err = gopher.Resize("30x")
+	c.Assert(err, qt.IsNil)
+
 	// Test PNGs with alpha channel.
 	for _, img := range []string{"gopher-hero8.png", "gradient-circle.png"} {
 		orig := fetchImageForSpec(spec, c, img)
@@ -596,6 +594,7 @@ func TestImageOperationsGolden(t *testing.T) {
 			f.Invert(),
 			f.Hue(22),
 			f.Contrast(32.5),
+			f.Overlay(gopher.(images.ImageSource), 20, 30),
 		}
 
 		resized, err := orig.Fill("400x200 center")
@@ -680,7 +679,6 @@ func TestImageOperationsGolden(t *testing.T) {
 		f1.Close()
 		f2.Close()
 	}
-
 }
 
 func BenchmarkResizeParallel(b *testing.B) {
