@@ -16,6 +16,8 @@ package page
 import (
 	"sort"
 
+	"github.com/gohugoio/hugo/common/collections"
+
 	"github.com/gohugoio/hugo/resources/resource"
 
 	"github.com/gohugoio/hugo/compare"
@@ -37,6 +39,19 @@ type pageSorter struct {
 // pageBy is a closure used in the Sort.Less method.
 type pageBy func(p1, p2 Page) bool
 
+func getOrdinals(p1, p2 Page) (int, int) {
+	p1o, ok1 := p1.(collections.Order)
+	if !ok1 {
+		return -1, -1
+	}
+	p2o, ok2 := p2.(collections.Order)
+	if !ok2 {
+		return -1, -1
+	}
+
+	return p1o.Ordinal(), p2o.Ordinal()
+}
+
 // Sort stable sorts the pages given the receiver's sort order.
 func (by pageBy) Sort(pages Pages) {
 	ps := &pageSorter{
@@ -49,8 +64,12 @@ func (by pageBy) Sort(pages Pages) {
 var (
 
 	// DefaultPageSort is the default sort func for pages in Hugo:
-	// Order by Weight, Date, LinkTitle and then full file path.
+	// Order by Ordinal, Weight, Date, LinkTitle and then full file path.
 	DefaultPageSort = func(p1, p2 Page) bool {
+		o1, o2 := getOrdinals(p1, p2)
+		if o1 != o2 && o1 != -1 && o2 != -1 {
+			return o1 < o2
+		}
 		if p1.Weight() == p2.Weight() {
 			if p1.Date().Unix() == p2.Date().Unix() {
 				c := compare.Strings(p1.LinkTitle(), p2.LinkTitle())
@@ -77,7 +96,6 @@ var (
 	}
 
 	lessPageLanguage = func(p1, p2 Page) bool {
-
 		if p1.Language().Weight == p2.Language().Weight {
 			if p1.Date().Unix() == p2.Date().Unix() {
 				c := compare.Strings(p1.LinkTitle(), p2.LinkTitle())
@@ -155,7 +173,6 @@ func SortByDefault(pages Pages) {
 //
 // This may safely be executed  in parallel.
 func (p Pages) ByTitle() Pages {
-
 	const key = "pageSort.ByTitle"
 
 	pages, _ := spc.get(key, pageBy(lessPageTitle).Sort, p)
@@ -168,7 +185,6 @@ func (p Pages) ByTitle() Pages {
 //
 // This may safely be executed  in parallel.
 func (p Pages) ByLinkTitle() Pages {
-
 	const key = "pageSort.ByLinkTitle"
 
 	pages, _ := spc.get(key, pageBy(lessPageLinkTitle).Sort, p)
@@ -182,7 +198,6 @@ func (p Pages) ByLinkTitle() Pages {
 //
 // This may safely be executed  in parallel.
 func (p Pages) ByDate() Pages {
-
 	const key = "pageSort.ByDate"
 
 	pages, _ := spc.get(key, pageBy(lessPageDate).Sort, p)
@@ -196,7 +211,6 @@ func (p Pages) ByDate() Pages {
 //
 // This may safely be executed  in parallel.
 func (p Pages) ByPublishDate() Pages {
-
 	const key = "pageSort.ByPublishDate"
 
 	pages, _ := spc.get(key, pageBy(lessPagePubDate).Sort, p)
@@ -210,7 +224,6 @@ func (p Pages) ByPublishDate() Pages {
 //
 // This may safely be executed  in parallel.
 func (p Pages) ByExpiryDate() Pages {
-
 	const key = "pageSort.ByExpiryDate"
 
 	expDate := func(p1, p2 Page) bool {
@@ -228,7 +241,6 @@ func (p Pages) ByExpiryDate() Pages {
 //
 // This may safely be executed  in parallel.
 func (p Pages) ByLastmod() Pages {
-
 	const key = "pageSort.ByLastmod"
 
 	date := func(p1, p2 Page) bool {
@@ -246,11 +258,9 @@ func (p Pages) ByLastmod() Pages {
 //
 // This may safely be executed  in parallel.
 func (p Pages) ByLength() Pages {
-
 	const key = "pageSort.ByLength"
 
 	length := func(p1, p2 Page) bool {
-
 		p1l, ok1 := p1.(resource.LengthProvider)
 		p2l, ok2 := p2.(resource.LengthProvider)
 
@@ -276,7 +286,6 @@ func (p Pages) ByLength() Pages {
 //
 // This may safely be executed  in parallel.
 func (p Pages) ByLanguage() Pages {
-
 	const key = "pageSort.ByLanguage"
 
 	pages, _ := spc.get(key, pageBy(lessPageLanguage).Sort, p)
@@ -346,7 +355,6 @@ func (p Pages) ByParam(paramsKey interface{}) Pages {
 		s2 := cast.ToString(v2)
 
 		return compare.LessStrings(s1, s2)
-
 	}
 
 	pages, _ := spc.get(key, pageBy(paramsKeyComparator).Sort, p)
