@@ -20,6 +20,8 @@ import (
 	"time"
 
 	"github.com/gohugoio/hugo/hugofs/files"
+	"github.com/gohugoio/hugo/identity"
+	"github.com/gohugoio/hugo/tpl"
 
 	"github.com/gohugoio/hugo/modules"
 
@@ -83,11 +85,12 @@ func newTestPathSpecFor(cfg config.Provider) *helpers.PathSpec {
 }
 
 type testPage struct {
+	kind        string
 	description string
 	title       string
 	linkTitle   string
-
-	section string
+	lang        string
+	section     string
 
 	content string
 
@@ -125,8 +128,8 @@ func (p *testPage) AlternativeOutputFormats() OutputFormats {
 
 func (p *testPage) Author() Author {
 	return Author{}
-
 }
+
 func (p *testPage) Authors() AuthorList {
 	return nil
 }
@@ -162,6 +165,7 @@ func (p *testPage) Sitemap() config.Sitemap {
 func (p *testPage) Layout() string {
 	return ""
 }
+
 func (p *testPage) Date() time.Time {
 	return p.date
 }
@@ -218,6 +222,10 @@ func (p *testPage) GetPage(ref string) (Page, error) {
 	panic("not implemented")
 }
 
+func (p *testPage) GetPageWithTemplateInfo(info tpl.Info, ref string) (Page, error) {
+	panic("not implemented")
+}
+
 func (p *testPage) GetParam(key string) interface{} {
 	panic("not implemented")
 }
@@ -291,11 +299,11 @@ func (p *testPage) Keywords() []string {
 }
 
 func (p *testPage) Kind() string {
-	panic("not implemented")
+	return p.kind
 }
 
 func (p *testPage) Lang() string {
-	panic("not implemented")
+	return p.lang
 }
 
 func (p *testPage) Language() *langs.Language {
@@ -565,6 +573,10 @@ func (p *testPage) WordCount() int {
 	panic("not implemented")
 }
 
+func (p *testPage) GetIdentity() identity.Identity {
+	panic("not implemented")
+}
+
 func createTestPages(num int) Pages {
 	pages := make(Pages, num)
 
