@@ -14,19 +14,21 @@
 package babel
 
 import (
+	"bytes"
 	"io"
-	"os"
-	"os/exec"
 	"path/filepath"
 	"strconv"
 
+	"github.com/cli/safeexec"
+	"github.com/gohugoio/hugo/common/hexec"
+	"github.com/gohugoio/hugo/common/loggers"
+
 	"github.com/gohugoio/hugo/common/hugo"
 	"github.com/gohugoio/hugo/resources/internal"
 
 	"github.com/mitchellh/mapstructure"
 
 	"github.com/gohugoio/hugo/common/herrors"
-	"github.com/gohugoio/hugo/hugofs"
 	"github.com/gohugoio/hugo/resources"
 	"github.com/gohugoio/hugo/resources/resource"
 	"github.com/pkg/errors"
@@ -50,6 +52,7 @@ func DecodeOptions(m map[string]interface{}) (opts Options, err error) {
 	err = mapstructure.WeakDecode(m, &opts)
 	return
 }
+
 func (opts Options) toArgs() []string {
 	var args []string
 
@@ -106,11 +109,10 @@ func (t *babelTransformation) Transform(ctx *resources.ResourceTransformationCtx
 
 	binary := csiBinPath
 
-	if _, err := exec.LookPath(binary); err != nil {
+	if _, err := safeexec.LookPath(binary); err != nil {
 		// Try PATH
 		binary = binaryName
-		if _, err := exec.LookPath(binary); err != nil {
-
+		if _, err := safeexec.LookPath(binary); err != nil {
 			// This may be on a CI server etc. Will fall back to pre-built assets.
 			return herrors.ErrFeatureNotAvailable
 		}
@@ -119,6 +121,9 @@ func (t *babelTransformation) Transform(ctx *resources.ResourceTransformationCtx
 	var configFile string
 	logger := t.rs.Logger
 
+	var errBuf bytes.Buffer
+	infoW := loggers.LoggerToWriterWithPrefix(logger.Info(), "babel")
+
 	if t.options.Config != "" {
 		configFile = t.options.Config
 	} else {
@@ -127,25 +132,19 @@ func (t *babelTransformation) Transform(ctx *resources.ResourceTransformationCtx
 
 	configFile = filepath.Clean(configFile)
 
-	// We need an abolute filename to the config file.
+	// We need an absolute filename to the config file.
 	if !filepath.IsAbs(configFile) {
-		// We resolve this against the virtual Work filesystem, to allow
-		// this config file to live in one of the themes if needed.
-		fi, err := t.rs.BaseFs.Work.Stat(configFile)
-		if err != nil {
-			if t.options.Config != "" {
-				// Only fail if the user specificed config file is not found.
-				return errors.Wrapf(err, "babel config %q not found:", configFile)
-			}
-		} else {
-			configFile = fi.(hugofs.FileMetaInfo).Meta().Filename()
+		configFile = t.rs.BaseFs.ResolveJSConfigFile(configFile)
+		if configFile == "" && t.options.Config != "" {
+			// Only fail if the user specified config file is not found.
+			return errors.Errorf("babel config %q not found:", configFile)
 		}
 	}
 
 	var cmdArgs []string
 
 	if configFile != "" {
-		logger.INFO.Println("babel: use config file", configFile)
+		logger.Infoln("babel: use config file", configFile)
 		cmdArgs = []string{"--config-file", configFile}
 	}
 
@@ -154,11 +153,14 @@ func (t *babelTransformation) Transform(ctx *resources.ResourceTransformationCtx
 	}
 	cmdArgs = append(cmdArgs, "--filename="+ctx.SourcePath)
 
-	cmd := exec.Command(binary, cmdArgs...)
+	cmd, err := hexec.SafeCommand(binary, cmdArgs...)
+	if err != nil {
+		return err
+	}
 
 	cmd.Stdout = ctx.To
-	cmd.Stderr = os.Stderr
-	cmd.Env = hugo.GetExecEnviron(t.rs.Cfg)
+	cmd.Stderr = io.MultiWriter(infoW, &errBuf)
+	cmd.Env = hugo.GetExecEnviron(t.rs.WorkingDir, t.rs.Cfg, t.rs.BaseFs.Assets.Fs)
 
 	stdin, err := cmd.StdinPipe()
 	if err != nil {
@@ -172,7 +174,7 @@ func (t *babelTransformation) Transform(ctx *resources.ResourceTransformationCtx
 
 	err = cmd.Run()
 	if err != nil {
-		return err
+		return errors.Wrap(err, errBuf.String())
 	}
 
 	return nil
