@@ -76,7 +76,8 @@ func TestToBuildOptions(t *testing.T) {
 
 	opts, err = toBuildOptions(Options{
 		Target: "es2018", Format: "cjs", Minify: true, mediaType: media.JavascriptType,
-		SourceMap: "inline"})
+		SourceMap: "inline",
+	})
 	c.Assert(err, qt.IsNil)
 	c.Assert(opts, qt.DeepEquals, api.BuildOptions{
 		Bundle:            true,
@@ -93,7 +94,8 @@ func TestToBuildOptions(t *testing.T) {
 
 	opts, err = toBuildOptions(Options{
 		Target: "es2018", Format: "cjs", Minify: true, mediaType: media.JavascriptType,
-		SourceMap: "inline"})
+		SourceMap: "inline",
+	})
 	c.Assert(err, qt.IsNil)
 	c.Assert(opts, qt.DeepEquals, api.BuildOptions{
 		Bundle:            true,
@@ -107,5 +109,4 @@ func TestToBuildOptions(t *testing.T) {
 			Loader: api.LoaderJS,
 		},
 	})
-
 }
