@@ -1,17 +1,14 @@
 package resources
 
 import (
-	"path/filepath"
-	"testing"
-
-	"github.com/gohugoio/hugo/htesting/hqt"
-
 	"image"
 	"io"
 	"io/ioutil"
 	"os"
+	"path/filepath"
 	"runtime"
 	"strings"
+	"testing"
 
 	"github.com/gohugoio/hugo/langs"
 	"github.com/gohugoio/hugo/modules"
@@ -28,8 +25,10 @@ import (
 	"github.com/spf13/viper"
 )
 
-func newTestResourceSpec(c *qt.C) *Spec {
-	return newTestResourceSpecForBaseURL(c, "https://example.com/")
+type specDescriptor struct {
+	baseURL string
+	c       *qt.C
+	fs      afero.Fs
 }
 
 func createTestCfg() *viper.Viper {
@@ -51,10 +50,23 @@ func createTestCfg() *viper.Viper {
 	cfg.Set("allModules", modules.Modules{mod})
 
 	return cfg
-
 }
 
-func newTestResourceSpecForBaseURL(c *qt.C, baseURL string) *Spec {
+func newTestResourceSpec(desc specDescriptor) *Spec {
+	baseURL := desc.baseURL
+	if baseURL == "" {
+		baseURL = "https://example.com/"
+	}
+
+	afs := desc.fs
+	if afs == nil {
+		afs = afero.NewMemMapFs()
+	}
+
+	afs = hugofs.NewBaseFileDecorator(afs)
+
+	c := desc.c
+
 	cfg := createTestCfg()
 	cfg.Set("baseURL", baseURL)
 
@@ -66,7 +78,8 @@ func newTestResourceSpecForBaseURL(c *qt.C, baseURL string) *Spec {
 
 	cfg.Set("imaging", imagingCfg)
 
-	fs := hugofs.NewMem(cfg)
+	fs := hugofs.NewFrom(afs, cfg)
+	fs.Destination = hugofs.NewCreateCountingFs(fs.Destination)
 
 	s, err := helpers.NewPathSpec(fs, cfg, nil)
 	c.Assert(err, qt.IsNil)
@@ -74,7 +87,7 @@ func newTestResourceSpecForBaseURL(c *qt.C, baseURL string) *Spec {
 	filecaches, err := filecache.NewCaches(s)
 	c.Assert(err, qt.IsNil)
 
-	spec, err := NewSpec(s, filecaches, nil, output.DefaultFormats, media.DefaultTypes)
+	spec, err := NewSpec(s, filecaches, nil, nil, nil, output.DefaultFormats, media.DefaultTypes)
 	c.Assert(err, qt.IsNil)
 	return spec
 }
@@ -88,11 +101,13 @@ func newTargetPaths(link string) func() page.TargetPaths {
 	}
 }
 
-func newTestResourceOsFs(c *qt.C) *Spec {
+func newTestResourceOsFs(c *qt.C) (*Spec, string) {
 	cfg := createTestCfg()
 	cfg.Set("baseURL", "https://example.com")
 
-	workDir, _ := ioutil.TempDir("", "hugores")
+	workDir, err := ioutil.TempDir("", "hugores")
+	c.Assert(err, qt.IsNil)
+	c.Assert(workDir, qt.Not(qt.Equals), "")
 
 	if runtime.GOOS == "darwin" && !strings.HasPrefix(workDir, "/private") {
 		// To get the entry folder in line with the rest. This its a little bit
@@ -102,7 +117,7 @@ func newTestResourceOsFs(c *qt.C) *Spec {
 
 	cfg.Set("workingDir", workDir)
 
-	fs := hugofs.NewFrom(hugofs.Os, cfg)
+	fs := hugofs.NewFrom(hugofs.NewBaseFileDecorator(hugofs.Os), cfg)
 	fs.Destination = &afero.MemMapFs{}
 
 	s, err := helpers.NewPathSpec(fs, cfg, nil)
@@ -111,32 +126,42 @@ func newTestResourceOsFs(c *qt.C) *Spec {
 	filecaches, err := filecache.NewCaches(s)
 	c.Assert(err, qt.IsNil)
 
-	spec, err := NewSpec(s, filecaches, nil, output.DefaultFormats, media.DefaultTypes)
+	spec, err := NewSpec(s, filecaches, nil, nil, nil, output.DefaultFormats, media.DefaultTypes)
 	c.Assert(err, qt.IsNil)
-	return spec
 
+	return spec, workDir
 }
 
-func fetchSunset(c *qt.C) *Image {
+func fetchSunset(c *qt.C) resource.Image {
 	return fetchImage(c, "sunset.jpg")
 }
 
-func fetchImage(c *qt.C, name string) *Image {
-	spec := newTestResourceSpec(c)
+func fetchImage(c *qt.C, name string) resource.Image {
+	spec := newTestResourceSpec(specDescriptor{c: c})
 	return fetchImageForSpec(spec, c, name)
 }
 
-func fetchImageForSpec(spec *Spec, c *qt.C, name string) *Image {
+func fetchImageForSpec(spec *Spec, c *qt.C, name string) resource.Image {
 	r := fetchResourceForSpec(spec, c, name)
-	c.Assert(r, hqt.IsSameType, &Image{})
-	return r.(*Image)
+
+	img := r.(resource.Image)
+
+	c.Assert(img, qt.Not(qt.IsNil))
+	c.Assert(img.(specProvider).getSpec(), qt.Not(qt.IsNil))
+
+	return img
 }
 
-func fetchResourceForSpec(spec *Spec, c *qt.C, name string) resource.ContentResource {
+func fetchResourceForSpec(spec *Spec, c *qt.C, name string, targetPathAddends ...string) resource.ContentResource {
 	src, err := os.Open(filepath.FromSlash("testdata/" + name))
 	c.Assert(err, qt.IsNil)
-
-	out, err := helpers.OpenFileForWriting(spec.Fs.Source, name)
+	workDir := spec.WorkingDir
+	if len(targetPathAddends) > 0 {
+		addends := strings.Join(targetPathAddends, "_")
+		name = addends + "_" + name
+	}
+	targetFilename := filepath.Join(workDir, name)
+	out, err := helpers.OpenFileForWriting(spec.Fs.Source, targetFilename)
 	c.Assert(err, qt.IsNil)
 	_, err = io.Copy(out, src)
 	out.Close()
@@ -145,8 +170,9 @@ func fetchResourceForSpec(spec *Spec, c *qt.C, name string) resource.ContentReso
 
 	factory := newTargetPaths("/a")
 
-	r, err := spec.New(ResourceSourceDescriptor{Fs: spec.Fs.Source, TargetPaths: factory, LazyPublish: true, SourceFilename: name})
+	r, err := spec.New(ResourceSourceDescriptor{Fs: spec.Fs.Source, TargetPaths: factory, LazyPublish: true, RelTargetFilename: name, SourceFilename: targetFilename})
 	c.Assert(err, qt.IsNil)
+	c.Assert(r, qt.Not(qt.IsNil))
 
 	return r.(resource.ContentResource)
 }
