@@ -5,11 +5,12 @@ import (
 	"io/ioutil"
 	"log"
 	"os"
-	"os/exec"
 	"path/filepath"
 	"regexp"
 	"strings"
 
+	"github.com/gohugoio/hugo/common/hexec"
+
 	"github.com/gohugoio/hugo/common/hugio"
 
 	"github.com/spf13/afero"
@@ -35,7 +36,6 @@ func main() {
 
 	goimports(htmlRoot)
 	gofmt(forkRoot)
-
 }
 
 const (
@@ -97,36 +97,41 @@ package parse
 	}
 
 	return content
-
 }
 
 var goPackages = []goPackage{
-	goPackage{srcPkg: "text/template", dstPkg: "texttemplate",
-		replacer: func(name, content string) string { return textTemplateReplacers.Replace(commonReplace(name, content)) }},
-	goPackage{srcPkg: "html/template", dstPkg: "htmltemplate", replacer: func(name, content string) string {
-		if strings.HasSuffix(name, "content.go") {
-			// Remove template.HTML types. We need to use the Go types.
-			content = removeAll(`(?s)// Strings of content.*?\)\n`, content)
-		}
-
-		content = commonReplace(name, content)
-
-		return htmlTemplateReplacers.Replace(content)
+	{
+		srcPkg: "text/template", dstPkg: "texttemplate",
+		replacer: func(name, content string) string { return textTemplateReplacers.Replace(commonReplace(name, content)) },
 	},
+	{
+		srcPkg: "html/template", dstPkg: "htmltemplate", replacer: func(name, content string) string {
+			if strings.HasSuffix(name, "content.go") {
+				// Remove template.HTML types. We need to use the Go types.
+				content = removeAll(`(?s)// Strings of content.*?\)\n`, content)
+			}
+
+			content = commonReplace(name, content)
+
+			return htmlTemplateReplacers.Replace(content)
+		},
 		rewriter: func(name string) {
 			for _, s := range []string{"CSS", "HTML", "HTMLAttr", "JS", "JSStr", "URL", "Srcset"} {
 				rewrite(name, fmt.Sprintf("%s -> htmltemplate.%s", s, s))
 			}
 			rewrite(name, `"text/template/parse" -> "github.com/gohugoio/hugo/tpl/internal/go_templates/texttemplate/parse"`)
-		}},
-	goPackage{srcPkg: "internal/fmtsort", dstPkg: "fmtsort", rewriter: func(name string) {
+		},
+	},
+	{srcPkg: "internal/fmtsort", dstPkg: "fmtsort", rewriter: func(name string) {
 		rewrite(name, `"internal/fmtsort" -> "github.com/gohugoio/hugo/tpl/internal/go_templates/fmtsort"`)
 	}},
-	goPackage{srcPkg: "internal/testenv", dstPkg: "testenv",
+	{
+		srcPkg: "internal/testenv", dstPkg: "testenv",
 		replacer: func(name, content string) string { return testEnvReplacers.Replace(content) }, rewriter: func(name string) {
 			rewrite(name, `"internal/testenv" -> "github.com/gohugoio/hugo/tpl/internal/go_templates/testenv"`)
-		}},
-	goPackage{srcPkg: "internal/cfg", dstPkg: "cfg", rewriter: func(name string) {
+		},
+	},
+	{srcPkg: "internal/cfg", dstPkg: "cfg", rewriter: func(name string) {
 		rewrite(name, `"internal/cfg" -> "github.com/gohugoio/hugo/tpl/internal/go_templates/cfg"`)
 	}},
 }
@@ -196,11 +201,10 @@ func doWithGoFiles(dir string,
 func removeAll(expression, content string) string {
 	re := regexp.MustCompile(expression)
 	return re.ReplaceAllString(content, "")
-
 }
 
 func rewrite(filename, rule string) {
-	cmf := exec.Command("gofmt", "-w", "-r", rule, filename)
+	cmf, _ := hexec.SafeCommand("gofmt", "-w", "-r", rule, filename)
 	out, err := cmf.CombinedOutput()
 	if err != nil {
 		log.Fatal("gofmt failed:", string(out))
@@ -208,7 +212,7 @@ func rewrite(filename, rule string) {
 }
 
 func goimports(dir string) {
-	cmf := exec.Command("goimports", "-w", dir)
+	cmf, _ := hexec.SafeCommand("goimports", "-w", dir)
 	out, err := cmf.CombinedOutput()
 	if err != nil {
 		log.Fatal("goimports failed:", string(out))
@@ -216,7 +220,7 @@ func goimports(dir string) {
 }
 
 func gofmt(dir string) {
-	cmf := exec.Command("gofmt", "-w", dir)
+	cmf, _ := hexec.SafeCommand("gofmt", "-w", dir)
 	out, err := cmf.CombinedOutput()
 	if err != nil {
 		log.Fatal("gofmt failed:", string(out))
