@@ -66,7 +66,8 @@ func TestComplement(t *testing.T) {
 		{"error", []interface{}{[]string{"c", "d"}, []string{"a", "b"}}, false},
 		{[]string{"a", "b", "c"}, []interface{}{[][]string{{"c", "d"}}}, false},
 		{
-			[]interface{}{[][]string{{"c", "d"}}}, []interface{}{[]string{"c", "d"}, []string{"a", "b"}},
+			[]interface{}{[][]string{{"c", "d"}}},
+			[]interface{}{[]string{"c", "d"}, []string{"a", "b"}},
 			[]interface{}{[][]string{{"c", "d"}}},
 		},
 	} {
@@ -93,5 +94,4 @@ func TestComplement(t *testing.T) {
 	c.Assert(err, qt.Not(qt.IsNil))
 	_, err = ns.Complement([]string{"a", "b"})
 	c.Assert(err, qt.Not(qt.IsNil))
-
 }
