@@ -39,6 +39,20 @@ func init() {
 			[][2]string{},
 		)
 
+		ns.AddMethodMapping(ctx.Complement,
+			[]string{"complement"},
+			[][2]string{
+				{`{{ slice "a" "b" "c" "d" "e" "f" | complement (slice "b" "c") (slice "d" "e")  }}`, `[a f]`},
+			},
+		)
+
+		ns.AddMethodMapping(ctx.SymDiff,
+			[]string{"symdiff"},
+			[][2]string{
+				{`{{ slice 1 2 3 | symdiff (slice 3 4) }}`, `[1 2 4]`},
+			},
+		)
+
 		ns.AddMethodMapping(ctx.Delimit,
 			[]string{"delimit"},
 			[][2]string{
@@ -102,10 +116,12 @@ func init() {
 			[][2]string{
 				{
 					`{{ (querify "foo" 1 "bar" 2 "baz" "with spaces" "qux" "this&that=those") | safeHTML }}`,
-					`bar=2&baz=with+spaces&foo=1&qux=this%26that%3Dthose`},
+					`bar=2&baz=with+spaces&foo=1&qux=this%26that%3Dthose`,
+				},
 				{
 					`<a href="https://www.google.com?{{ (querify "q" "test" "page" 3) | safeURL }}">Search</a>`,
-					`<a href="https://www.google.com?page=3&amp;q=test">Search</a>`},
+					`<a href="https://www.google.com?page=3&amp;q=test">Search</a>`,
+				},
 			},
 		)
 
@@ -169,8 +185,25 @@ func init() {
 			},
 		)
 
-		return ns
+		ns.AddMethodMapping(ctx.Merge,
+			[]string{"merge"},
+			[][2]string{
+				{
+					`{{ dict "title" "Hugo Rocks!" | collections.Merge (dict "title" "Default Title" "description" "Yes, Hugo Rocks!") | sort }}`,
+					`[Yes, Hugo Rocks! Hugo Rocks!]`,
+				},
+				{
+					`{{  merge (dict "title" "Default Title" "description" "Yes, Hugo Rocks!") (dict "title" "Hugo Rocks!") | sort }}`,
+					`[Yes, Hugo Rocks! Hugo Rocks!]`,
+				},
+				{
+					`{{  merge (dict "title" "Default Title" "description" "Yes, Hugo Rocks!") (dict "title" "Hugo Rocks!") (dict "extra" "For reals!") | sort }}`,
+					`[Yes, Hugo Rocks! For reals! Hugo Rocks!]`,
+				},
+			},
+		)
 
+		return ns
 	}
 
 	internal.AddTemplateFuncsNamespace(f)
