@@ -19,11 +19,12 @@ import (
 	"sort"
 	"strings"
 
+	"github.com/gohugoio/hugo/common/maps"
 	"github.com/gohugoio/hugo/tpl/compare"
 	"github.com/spf13/cast"
 )
 
-var comp = compare.New()
+var sortComp = compare.New(true)
 
 // Sort returns a sorted sequence.
 func (ns *Namespace) Sort(seq interface{}, args ...interface{}) (interface{}, error) {
@@ -31,21 +32,23 @@ func (ns *Namespace) Sort(seq interface{}, args ...interface{}) (interface{}, er
 		return nil, errors.New("sequence must be provided")
 	}
 
-	seqv := reflect.ValueOf(seq)
-	seqv, isNil := indirect(seqv)
+	seqv, isNil := indirect(reflect.ValueOf(seq))
 	if isNil {
 		return nil, errors.New("can't iterate over a nil value")
 	}
 
+	var sliceType reflect.Type
 	switch seqv.Kind() {
-	case reflect.Array, reflect.Slice, reflect.Map:
-		// ok
+	case reflect.Array, reflect.Slice:
+		sliceType = seqv.Type()
+	case reflect.Map:
+		sliceType = reflect.SliceOf(seqv.Type().Elem())
 	default:
 		return nil, errors.New("can't sort " + reflect.ValueOf(seq).Type().String())
 	}
 
 	// Create a list of pairs that will be used to do the sort
-	p := pairList{SortAsc: true, SliceType: reflect.SliceOf(seqv.Type().Elem())}
+	p := pairList{SortAsc: true, SliceType: sliceType}
 	p.Pairs = make([]pair, seqv.Len())
 
 	var sortByField string
@@ -73,11 +76,19 @@ func (ns *Namespace) Sort(seq interface{}, args ...interface{}) (interface{}, er
 			} else {
 				v := p.Pairs[i].Value
 				var err error
-				for _, elemName := range path {
+				for i, elemName := range path {
 					v, err = evaluateSubElem(v, elemName)
 					if err != nil {
 						return nil, err
 					}
+					if !v.IsValid() {
+						continue
+					}
+					// Special handling of lower cased maps.
+					if params, ok := v.Interface().(maps.Params); ok {
+						v = reflect.ValueOf(params.Get(path[i+1:]...))
+						break
+					}
 				}
 				p.Pairs[i].Key = v
 			}
@@ -87,6 +98,7 @@ func (ns *Namespace) Sort(seq interface{}, args ...interface{}) (interface{}, er
 		keys := seqv.MapKeys()
 		for i := 0; i < seqv.Len(); i++ {
 			p.Pairs[i].Value = seqv.MapIndex(keys[i])
+
 			if sortByField == "" {
 				p.Pairs[i].Key = keys[i]
 			} else if sortByField == "value" {
@@ -94,11 +106,19 @@ func (ns *Namespace) Sort(seq interface{}, args ...interface{}) (interface{}, er
 			} else {
 				v := p.Pairs[i].Value
 				var err error
-				for _, elemName := range path {
+				for i, elemName := range path {
 					v, err = evaluateSubElem(v, elemName)
 					if err != nil {
 						return nil, err
 					}
+					if !v.IsValid() {
+						continue
+					}
+					// Special handling of lower cased maps.
+					if params, ok := v.Interface().(maps.Params); ok {
+						v = reflect.ValueOf(params.Get(path[i+1:]...))
+						break
+					}
 				}
 				p.Pairs[i].Key = v
 			}
@@ -131,15 +151,16 @@ func (p pairList) Less(i, j int) bool {
 	if iv.IsValid() {
 		if jv.IsValid() {
 			// can only call Interface() on valid reflect Values
-			return comp.Lt(iv.Interface(), jv.Interface())
+			return sortComp.Lt(iv.Interface(), jv.Interface())
 		}
+
 		// if j is invalid, test i against i's zero value
-		return comp.Lt(iv.Interface(), reflect.Zero(iv.Type()))
+		return sortComp.Lt(iv.Interface(), reflect.Zero(iv.Type()))
 	}
 
 	if jv.IsValid() {
 		// if i is invalid, test j against j's zero value
-		return comp.Lt(reflect.Zero(jv.Type()), jv.Interface())
+		return sortComp.Lt(reflect.Zero(jv.Type()), jv.Interface())
 	}
 
 	return false
