@@ -43,7 +43,7 @@ type Namespace struct {
 func (*Namespace) Default(dflt interface{}, given ...interface{}) (interface{}, error) {
 	// given is variadic because the following construct will not pass a piped
 	// argument when the key is missing:  {{ index . "key" | default "foo" }}
-	// The Go template will complain that we got 1 argument when we expectd 2.
+	// The Go template will complain that we got 1 argument when we expected 2.
 
 	if len(given) == 0 {
 		return dflt, nil
@@ -252,6 +252,11 @@ func (ns *Namespace) compareGet(a interface{}, b interface{}) (float64, float64)
 		case timeType:
 			left = float64(toTimeUnix(av))
 		}
+	case reflect.Bool:
+		left = 0
+		if av.Bool() {
+			left = 1
+		}
 	}
 
 	bv := reflect.ValueOf(b)
@@ -275,6 +280,11 @@ func (ns *Namespace) compareGet(a interface{}, b interface{}) (float64, float64)
 		case timeType:
 			right = float64(toTimeUnix(bv))
 		}
+	case reflect.Bool:
+		right = 0
+		if bv.Bool() {
+			right = 1
+		}
 	}
 
 	if ns.caseInsensitive && leftStr != nil && rightStr != nil {
