@@ -108,14 +108,14 @@ func TestGetCSV(t *testing.T) {
 		got, err := ns.GetCSV(test.sep, test.url)
 
 		if _, ok := test.expect.(bool); ok {
-			c.Assert(int(ns.deps.Log.ErrorCounter.Count()), qt.Equals, 1)
-			//c.Assert(err, msg, qt.Not(qt.IsNil))
+			c.Assert(int(ns.deps.Log.LogCounters().ErrorCounter.Count()), qt.Equals, 1)
+			// c.Assert(err, msg, qt.Not(qt.IsNil))
 			c.Assert(got, qt.IsNil)
 			continue
 		}
 
 		c.Assert(err, qt.IsNil, msg)
-		c.Assert(int(ns.deps.Log.ErrorCounter.Count()), qt.Equals, 0)
+		c.Assert(int(ns.deps.Log.LogCounters().ErrorCounter.Count()), qt.Equals, 0)
 		c.Assert(got, qt.Not(qt.IsNil), msg)
 		c.Assert(got, qt.DeepEquals, test.expect, msg)
 
@@ -157,6 +157,11 @@ func TestGetJSON(t *testing.T) {
 			"",
 			false,
 		},
+		{
+			`pass/üńīçøðê-url.json`,
+			`{"gomeetup":["Sydney","San Francisco","Stockholm"]}`,
+			map[string]interface{}{"gomeetup": []interface{}{"Sydney", "San Francisco", "Stockholm"}},
+		},
 	} {
 
 		msg := qt.Commentf("Test %d", i)
@@ -193,17 +198,23 @@ func TestGetJSON(t *testing.T) {
 		got, _ := ns.GetJSON(test.url)
 
 		if _, ok := test.expect.(bool); ok {
-			c.Assert(int(ns.deps.Log.ErrorCounter.Count()), qt.Equals, 1)
-			//c.Assert(err, msg, qt.Not(qt.IsNil))
+			c.Assert(int(ns.deps.Log.LogCounters().ErrorCounter.Count()), qt.Equals, 1)
+			// c.Assert(err, msg, qt.Not(qt.IsNil))
 			continue
 		}
 
-		c.Assert(int(ns.deps.Log.ErrorCounter.Count()), qt.Equals, 0, msg)
+		c.Assert(int(ns.deps.Log.LogCounters().ErrorCounter.Count()), qt.Equals, 0, msg)
 		c.Assert(got, qt.Not(qt.IsNil), msg)
 		c.Assert(got, qt.DeepEquals, test.expect)
 	}
 }
 
+func TestJoinURL(t *testing.T) {
+	t.Parallel()
+	c := qt.New(t)
+	c.Assert(joinURL([]interface{}{"https://foo?id=", 32}), qt.Equals, "https://foo?id=32")
+}
+
 func TestParseCSV(t *testing.T) {
 	t.Parallel()
 	c := qt.New(t)
