@@ -40,9 +40,7 @@ import (
 	"github.com/spf13/viper"
 )
 
-var (
-	logger = loggers.NewErrorLogger()
-)
+var logger = loggers.NewErrorLogger()
 
 func newTestConfig() config.Provider {
 	v := viper.New()
@@ -100,6 +98,7 @@ func TestTemplateFuncsExamples(t *testing.T) {
 	depsCfg := newDepsConfig(v)
 	depsCfg.Fs = fs
 	d, err := deps.New(depsCfg)
+	defer d.Close()
 	c.Assert(err, qt.IsNil)
 
 	var data struct {
@@ -165,6 +164,7 @@ func TestPartialCached(t *testing.T) {
 
 	de, err := deps.New(config)
 	c.Assert(err, qt.IsNil)
+	defer de.Close()
 	c.Assert(de.LoadResources(), qt.IsNil)
 
 	ns := partials.New(de)
@@ -188,7 +188,6 @@ func TestPartialCached(t *testing.T) {
 			t.Fatalf("cache mismatch")
 		}
 	}
-
 }
 
 func BenchmarkPartial(b *testing.B) {
@@ -219,6 +218,7 @@ func doBenchmarkPartial(b *testing.B, f func(ns *partials.Namespace) error) {
 
 	de, err := deps.New(config)
 	c.Assert(err, qt.IsNil)
+	defer de.Close()
 	c.Assert(de.LoadResources(), qt.IsNil)
 
 	ns := partials.New(de)
