@@ -32,7 +32,7 @@ func init() {
 		ns.AddMethodMapping(ctx.Emojify,
 			[]string{"emojify"},
 			[][2]string{
-				{`{{ "I :heart: Hugo" | emojify }}`, `I ❤ Hugo`},
+				{`{{ "I :heart: Hugo" | emojify }}`, `I ❤️ Hugo`},
 			},
 		)
 
@@ -46,13 +46,16 @@ func init() {
 			[][2]string{
 				{
 					`{{ htmlEscape "Cathal Garvey & The Sunshine Band <cathal@foo.bar>" | safeHTML}}`,
-					`Cathal Garvey &amp; The Sunshine Band &lt;cathal@foo.bar&gt;`},
+					`Cathal Garvey &amp; The Sunshine Band &lt;cathal@foo.bar&gt;`,
+				},
 				{
 					`{{ htmlEscape "Cathal Garvey & The Sunshine Band <cathal@foo.bar>"}}`,
-					`Cathal Garvey &amp;amp; The Sunshine Band &amp;lt;cathal@foo.bar&amp;gt;`},
+					`Cathal Garvey &amp;amp; The Sunshine Band &amp;lt;cathal@foo.bar&amp;gt;`,
+				},
 				{
 					`{{ htmlEscape "Cathal Garvey & The Sunshine Band <cathal@foo.bar>" | htmlUnescape | safeHTML }}`,
-					`Cathal Garvey & The Sunshine Band <cathal@foo.bar>`},
+					`Cathal Garvey & The Sunshine Band <cathal@foo.bar>`,
+				},
 			},
 		)
 
@@ -61,16 +64,20 @@ func init() {
 			[][2]string{
 				{
 					`{{ htmlUnescape "Cathal Garvey &amp; The Sunshine Band &lt;cathal@foo.bar&gt;" | safeHTML}}`,
-					`Cathal Garvey & The Sunshine Band <cathal@foo.bar>`},
+					`Cathal Garvey & The Sunshine Band <cathal@foo.bar>`,
+				},
 				{
 					`{{"Cathal Garvey &amp;amp; The Sunshine Band &amp;lt;cathal@foo.bar&amp;gt;" | htmlUnescape | htmlUnescape | safeHTML}}`,
-					`Cathal Garvey & The Sunshine Band <cathal@foo.bar>`},
+					`Cathal Garvey & The Sunshine Band <cathal@foo.bar>`,
+				},
 				{
 					`{{"Cathal Garvey &amp;amp; The Sunshine Band &amp;lt;cathal@foo.bar&amp;gt;" | htmlUnescape | htmlUnescape }}`,
-					`Cathal Garvey &amp; The Sunshine Band &lt;cathal@foo.bar&gt;`},
+					`Cathal Garvey &amp; The Sunshine Band &lt;cathal@foo.bar&gt;`,
+				},
 				{
 					`{{ htmlUnescape "Cathal Garvey &amp; The Sunshine Band &lt;cathal@foo.bar&gt;" | htmlEscape | safeHTML }}`,
-					`Cathal Garvey &amp; The Sunshine Band &lt;cathal@foo.bar&gt;`},
+					`Cathal Garvey &amp; The Sunshine Band &lt;cathal@foo.bar&gt;`,
+				},
 			},
 		)
 
@@ -104,7 +111,6 @@ func init() {
 		)
 
 		return ns
-
 	}
 
 	internal.AddTemplateFuncsNamespace(f)
